/*******************************************************************************************************************************
Program: 				Child Diet Analysis.do

Purpose: 				Descriptive Statistics for child diet data, calculating proportions and confidence intervals, performing a Pearson test, and 
						exporting the processed and aggregated data to an Excel spreadsheet for the purpose of creating descriptive statistics reports on 
						child dietary patterns within specified regions and socioeconomic categories

Input Data:				child_diet_analysis.dta (created in Child_Analysis_Merged_Data.do)

Outputs:				Child_Diet_Tables_final ANNEX.xlsx
						child_diet_analysis.csv

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/
clear
clear matrix

*** use cleaned data
use "${clean}\child_diet_analysis.dta", 


* general variables and statements
svyset hv021[pw=wt], strata(hv022) singleunit(centered)

g include = 0
replace include = 1 if inlist(region,25,51,52,53)

* re-organize values of region to create output in order: androy, anosy, atsimo andrefana, atsimo atsinanana
tab region

recode region (52=1 "Androy") (53=2 "Anosy") (51=3 "AtsimoAndrefana") (25=4 "AtismoAtsinanana"), pre(new)label(newreg)

tab region


********************************
********************************
*Below is the code for min diet
********************************
********************************
**# n_cat_loop
* write a program to implement the numerical loop
cap prog drop n_cat_loop
prog def n_cat_loop
  * 8 come from 4 regions * 2 poverty levels 
scalar n_cat = rowsof(VP)/8
local start = n_cat * 4 +1
forvalues j = 1/`=n_cat' {
	local end = `start'+3
	display `j' " start:"`start'
	display `j' " end:"`end'
	matselrc VP VP`j', r(`start'/`end')
	local start = `start' + 4 
}
mat VPT = VP1
local j = 2
 while (`j' <= `=n_cat') {
	mat VPT = (VPT,VP`j')
	local j = `j' + 1
}
matlist VPT
end


* n_cat for total pooled results across our 4 regions
cap prog drop n_cat_tot_loop
prog def n_cat_tot_loop
  * 2 come from 1 total * 2 outcome levels 
scalar n_cattot = rowsof(VP)/2
local starttot = n_cattot * 1 +1 // adjusted from 3 to 1?
forvalues j = 1/`=n_cattot' {
	local endtot = `starttot' // adjusted from +3 to +0
	display `j' " starttot:"`starttot'
	display `j' " endtot:"`endtot'
	matselrc VP VP`j', r(`starttot'/`endtot') 
	local starttot = `starttot' + 1 // adjusted from 4 to 1
}
mat VPT = VP1
local j = 2
 while (`j' <= `=n_cattot') {
	mat VPT = (VPT,VP`j')
	local j = `j' + 1
}
matlist VPT
end


**# Overall result without disaggregation
**Table ‎A-28: Proportion of Child MAD by Region (%)
svy, subpop(if include == 1): prop nt_mad, over(newregion)
* ereturn list (show all element options)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

* call loop
n_cat_loop

putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("key outcome MAD") modify
putexcel B3 = matrix(VPT), nfor(percent)


* overall result
svy, subpop(if include == 1): prop nt_mad
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop

putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns: use mean rather than tab here b/c no disaggregation
quietly svy, subpop(if include==1 & nt_mad!=.): mean nt_mad
matrix mad_tot_n=e(N_sub)
putexcel B14 = matrix(mad_tot_n), nfor(0)

* get Ns
svy, subpop(if include==1 & nt_mad!=.): tab newregion  
matrix mad_n=e(ObsSub)
matlist mad_n
putexcel B10 = matrix(mad_n), nfor(0)


** get Pearson test value
svy, subpop(if include==1): tab newregion nt_mad, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

** CIs for regional results
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** CIs for pooled results
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)


** Table A-29: Proportion of Child MAD by Gender of Household Head


svy, subpop(if include == 1): prop nt_mad, over(hh_head_female newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'

* call loop
n_cat_loop

putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("Table 1 headship") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(hh_head_female)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab hh_head_female
matrix fem_tot_n=e(ObsSub)'
matlist fem_tot_n
putexcel B14 = matrix(fem_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion hh_head_female, row
matrix fem_n=e(ObsSub)
matlist fem_n
putexcel B10 = matrix(fem_n), nfor(0)

* get Pearson test value
egen femalemad=group(nt_mad hh_head_female), label
svy, subpop(if include==1): tab newregion femalemad, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

** CIs for regional results

* confidence intervals
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-30: Proportion of Child MAD by Household Size (%)

** create categories for hhsize
recode hhsize (6/96 = 6 "6 plus"), gen(hhsize_cat)
recode hhsize (1/2 = 2 "2 or less") (6/96 = 6 "6 plus"), gen(hhsize_cat2)

svy, subpop(if include == 1 ): prop nt_mad, over(hhsize_cat2 newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("Table 2 hh size") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(hhsize_cat2)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab hhsize_cat2
matrix hhsize_tot_n=e(ObsSub)'
matlist hhsize_tot_n
putexcel B14 = matrix(hhsize_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion hhsize_cat2, row
matrix hhsize_n=e(ObsSub)
matlist hhsize_n
putexcel B10 = matrix(hhsize_n), nfor(0)

* get Pearson test value
egen sizemad=group(nt_mad hhsize_cat2), label
svy, subpop(if include==1): tab newregion sizemad, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)


* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)


**Sheet Table ‎A-31: Proportion of MAD by Age of Household Head (%)

** create categories for hhh age
recode hv220 (1/19 = 1 "19 or younger") (20/34 = 2 "20-34") (35/49 = 3 "35-49") (50/100 = 4 "50 plus"), gen(hhhage_cat)
recode hv220 (1/34 = 1 "34 or younger") (35/49 = 2 "35-49") (50/100 = 3 "50 plus"), gen(hhhage_cat2)

svy, subpop(if include == 1): prop nt_mad, over(hhhage_cat2 newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T3 head age") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(hhhage_cat2)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab hhhage_cat2
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion hhhage_cat2, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* get Pearson test value
egen hhhage_pov=group(nt_mad hhhage_cat2), label
svy, subpop(if include==1): tab newregion hhhage_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)


* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-32: Proportion of Child MAD by Education of Household Head (%)
recode education (0=0 "None") (1=1 "Incomplete Primary") (2/7 = 3 "Complete primary or higher"), gen(hheduc_cat)


svy, subpop(if include == 1): prop nt_mad, over(hheduc_cat newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T4 head educ") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(hheduc_cat)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab hheduc_cat
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion hheduc_cat, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* get Pearson test value
egen hhheduc_pov=group(nt_mad hheduc_cat), label
svy, subpop(if include==1): tab newregion hhheduc_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)


* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-33: Proportion of Child MAD by Number of Children Under 5 (%) 

recode v137 (4/12 = 4 "4 plus"), gen(childu5)

svy, subpop(if include == 1 & childu5 > 0): prop nt_mad, over(childu5 newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* call loop
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T5 children under 5") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(childu5)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT[1..rowsof(VPT), 2..colsof(VPT)]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab childu5
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n[1..rowsof(item_tot_n), 2..colsof(item_tot_n)]), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion childu5, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n[1..rowsof(item_n), 2..colsof(item_n)]), nfor(0)

* get Pearson test value
egen childu5_pov=group(nt_mad childu5), label
svy, subpop(if include==1): tab newregion childu5_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)


* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT[1..rowsof(VPT), 2..colsof(VPT)]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT[1..rowsof(VPT), 2..colsof(VPT)]), nfor(percent)

** Table ‎A-34: Proportion of Child MAD by Number of Dependents (0-14, 65+) (%) 
gen num_mbrs_dpndt=num_mbrs_14+num_mbrs_65
recode num_mbrs_dpndt (4/14 = 4 "4 plus"), gen(num_mbrs)
svy, subpop(if include == 1): prop nt_mad, over(num_mbrs newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* call loop
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T6 dependency") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(num_mbrs)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab num_mbrs
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion num_mbrs, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* get Pearson test value
egen dependency_pov=group(nt_mad num_mbrs), label
svy, subpop(if include==1): tab newregion dependency_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-35: Proportion of Child MAD by Literacy of Mother (%)
recode v155 (0=0 "None") (1/2 = 1 "Read part or whole sentence"), gen(lit_cat)

svy, subpop(if include == 1): prop nt_mad, over(lit_cat newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* call loop
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T7 mother's literacy (kids only") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(lit_cat)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab lit_cat
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion lit_cat, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* get Pearson test value
egen momlit_pov=group(nt_mad lit_cat), label
svy, subpop(if include==1): tab newregion momlit_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-36: Proportion of Child MAD by Occupation
recode v717 (0=1 "Not working") (4/5=2 "Agriculture") (1/3 6/8 10 96=3 "Other"), gen(mother_occup)

svy, subpop(if include == 1): prop nt_mad, over(mother_occup newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* call loop
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("T8 mothers occup (kids only)") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(mother_occup)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab mother_occup
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion mother_occup, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* get Pearson test value
egen momocp_pov=group(nt_mad mother_occup), label
svy, subpop(if include==1): tab newregion momocp_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)



** Table ‎A-37: Proportion of Child MAD by Household Possessions (%)
**# Radio
svy, subpop(if include == 1 & radio == 1): prop nt_mad, over(radio newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* Call loop (assuming you have defined this loop elsewhere)
n_cat_loop

putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("household possessions") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(radio)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab radio
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & radio!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen radio_pov = group(nt_mad radio), label
svy, subpop(if include == 1): tab newregion radio_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)



**# TV
svy, subpop(if include == 1 & television == 1) : prop nt_mad, over(television newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel C3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(television)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel C7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab television
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel C14 = matrix(item_tot_n), nfor(0)


* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & television!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel C10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen television_pov = group(nt_mad television ), label
svy, subpop(if include == 1): tab newregion television_pov, row
putexcel C8 = `e(p_Pear)'
putexcel C8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel C16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel C22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel C20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel C26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Phone
svy, subpop(if include == 1 & mobile_phone == 1): prop nt_mad, over(mobile_phone newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(mobile_phone)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel D7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab mobile_phone
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel D14 = matrix(item_tot_n), nfor(0)


* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. &  mobile_phone!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel D10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen mp_pov = group(nt_mad mobile_phone ), label
svy, subpop(if include == 1): tab newregion mp_pov, row
putexcel D8 = `e(p_Pear)'
putexcel D8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Bicycle
svy, subpop(if include == 1 & bicycle == 1): prop nt_mad, over(bicycle newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel E3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(bicycle )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel E7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab bicycle 
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel E14 = matrix(item_tot_n), nfor(0)


* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & bicycle!=.): tab newregion  
matrix item_n=e(ObsSub)
matlist item_n
putexcel E10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen bike_pov = group(nt_mad bicycle ), label
svy, subpop(if include == 1): tab newregion bike_pov, row
putexcel E7 = `e(p_Pear)'
putexcel E7 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel E16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel E22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel E20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel E26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)


**Table ‎A-38: Proportion of Child MAD by Water and Toilet (%)
**# Water

*Table for water _improve
svy, subpop(if include == 1): prop nt_mad, over(water_improve newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("housing water toilet") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(water_improve )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab water_improve
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion water_improve , row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* Get Pearson test value
egen water_pov = group(nt_mad water_improve ), label
svy, subpop(if include == 1): tab newregion water_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

**# Toilet
recode sani_improve (1/2 = 1 "Unimproved or Improved Toilet") (3=2 "Open Defecation"), gen(cmbtoilet)

*table for toilet improve
svy, subpop(if include == 1): prop nt_mad, over(cmbtoilet newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* Call loop 
n_cat_loop
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(cmbtoilet )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel D7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab cmbtoilet
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel D14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion cmbtoilet , row
matrix item_n=e(ObsSub)
matlist item_n
putexcel D10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen toilet_pov = group(nt_mad cmbtoilet), label
svy, subpop(if include == 1): tab newregion toilet_pov, row
putexcel D8 = `e(p_Pear)'
putexcel D8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT), nfor(percent)

** Table ‎A-39: Proportion of Child MAD by Roof (%)
**# Roof
svy, subpop(if include == 1): prop nt_mad, over(roof_type newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("housing roof floor") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(roof_type )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab roof_type
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion roof_type , row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* Get Pearson test value
egen roof_type_pov = group(nt_mad roof_type ), label
svy, subpop(if include == 1): tab newregion roof_type_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)


* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

** Table ‎A-40: Proportion of Child MAD by Floor (%)

svy, subpop(if include == 1): prop nt_mad, over(floor_type newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel F3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(floor_type )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel F7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab floor_type
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel F14 = matrix(item_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion floor_type , row
matrix item_n=e(ObsSub)
matlist item_n
putexcel F10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen floor_type_pov = group(nt_mad floor_type ), label
svy, subpop(if include == 1): tab newregion floor_type_pov, row
putexcel F8 = `e(p_Pear)'
putexcel F8 , overwr nfor(0.000)



* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel F16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel F22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel F20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel F26 = matrix(VPT), nfor(percent)

**Table ‎A-41/42: Proportion of Child MAD by Agricultural assets (%)
**# Animal Cart
svy, subpop(if include == 1 & animal_cart == 1): prop nt_mad, over(animal_cart newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("other assets") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(animal_cart )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab animal_cart
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel B14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & animal_cart!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen animal_cart_pov = group(nt_mad animal_cart ), label
svy, subpop(if include == 1): tab newregion animal_cart_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Land
svy, subpop(if include == 1 & own_agricland == 1): prop nt_mad, over(own_agricland newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* Call loop (assuming you have defined this loop elsewhere)
n_cat_loop
putexcel C3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_agricland )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel C7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_agricland
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel C14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_agricland!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel C10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen own_agricland_pov = group(nt_mad own_agricland ), label
svy, subpop(if include == 1): tab newregion own_agricland_pov, row
putexcel C8 = `e(p_Pear)'
putexcel C8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel C16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel C22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel C20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel C26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Phone
svy, subpop(if include == 1 & mobile_phone == 1): prop nt_mad, over(mobile_phone newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(mobile_phone )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel D7 =matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab mobile_phone
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel D14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & mobile_phone!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel D10 = matrix(item_n[1, 2]), nfor(0)


* Get Pearson test value
svy, subpop(if include == 1): tab newregion mp_pov, row
putexcel D8 = `e(p_Pear)'
putexcel D8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Bicycle
svy, subpop(if include == 1 & bicycle == 1): prop nt_mad, over(bicycle newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel E3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(bicycle )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel E7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab bicycle
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel E14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & bicycle!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel E10 =  matrix(item_n), nfor(0)


* Get Pearson test value
svy, subpop(if include == 1): tab newregion bike_pov, row
putexcel E8 = `e(p_Pear)'
putexcel E8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel E16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel E22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel E20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel E26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Any Livestock
svy, subpop(if include == 1 & own_livestock == 1): prop nt_mad, over(own_livestock newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("livestock") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_livestock  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_livestock 
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel B14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_livestock!=.): tab newregion  
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen own_livestock_pov = group(nt_mad own_livestock ), label
svy, subpop(if include == 1): tab newregion own_livestock_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Cow
svy, subpop(if include == 1 & own_cows == 1): prop nt_mad, over(own_cows newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel C3 = matrix(VPT), nfor(percent)


* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_cows  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel c7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_cows
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel c14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_cows!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel c10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen own_cows_pov = group(nt_mad own_cows ), label
svy, subpop(if include == 1): tab newregion own_cows_pov, row
putexcel C8 = `e(p_Pear)'
putexcel C8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel C16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel C22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel C20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel C26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Goats
svy, subpop(if include == 1 & own_goats == 1): prop nt_mad, over(own_goats newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_goats  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel D7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_goats
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel D14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.  & own_goats!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel D10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen own_goats_pov = group(nt_mad own_goats ), label
svy, subpop(if include == 1): tab newregion own_goats_pov, row
putexcel D8 = `e(p_Pear)'
putexcel D8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
**# Sheep
svy, subpop(if include == 1 & own_sheep == 1): prop nt_mad, over(own_sheep newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel E3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_sheep   )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel E7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_sheep
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel E14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_sheep!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel E10 =  matrix(item_n), nfor(0)



* Get Pearson test value
egen own_sheep_pov = group(nt_mad own_sheep ), label
svy, subpop(if include == 1): tab newregion own_sheep_pov, row
putexcel E8 = `e(p_Pear)'
putexcel E8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel E16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel E22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel E20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel E26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Poultry
svy, subpop(if include == 1 & own_poultry == 1): prop nt_mad, over(own_poultry newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel F3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_poultry  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel F7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_poultry
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel F14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_poultry!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel F10 = matrix(item_n), nfor(0)

* Get Pearson test value
egen own_poultry_pov = group(nt_mad own_poultry ), label
svy, subpop(if include == 1): tab newregion own_poultry_pov, row
putexcel F8 = `e(p_Pear)'
putexcel F8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel F16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel F22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel F20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel F26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Zebus
svy, subpop(if include == 1 & own_zebus == 1): prop nt_mad, over(own_zebus newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel G3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_zebus  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel G7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_zebus
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel G14 =  matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_zebus!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel G10 =  matrix(item_n), nfor(0)

* Get Pearson test value
egen own_zebus_pov = group(nt_mad own_zebus ), label
svy, subpop(if include == 1): tab newregion own_zebus_pov, row
putexcel G8 = `e(p_Pear)'
putexcel G8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel G16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel G22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel G20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel G26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Ducks
svy, subpop(if include == 1 & own_ducks == 1): prop nt_mad, over(own_ducks newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel H3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_ducks  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel H7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_ducks
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel H14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_ducks!=.): tab newregion 
matrix item_n=e(ObsSub)
matlist item_n
putexcel H10 = matrix(item_n), nfor(0)


* Get Pearson test value
egen own_ducks_pov = group(nt_mad own_ducks ), label
svy, subpop(if include == 1): tab newregion own_ducks_pov, row
putexcel H8 = `e(p_Pear)'
putexcel H8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel H16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel H22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel H20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel H26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

**# Pigs
svy, subpop(if include == 1 & own_pigs == 1): prop nt_mad, over(own_pigs newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel I3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(own_pigs  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel I7 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab own_pigs
matrix item_tot_n=e(N_sub)'
matlist item_tot_n
putexcel I14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=. & own_pigs!=.): tab newregion
matrix item_n=e(ObsSub)
matlist item_n
putexcel I10 = matrix(item_n), nfor(0)

* Get Pearson test value
egen own_pigs_pov = group(nt_mad own_pigs ), label
svy, subpop(if include == 1): tab newregion own_pigs_pov, row
putexcel I8 = `e(p_Pear)'
putexcel I8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel I16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel I22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel I20 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel I26 = matrix(VPT[1..rowsof(VPT), 2]), nfor(percent)

** Table ‎A-43: Proportion of Child MAD by Rural/Urban Location (%)
svy, subpop(if include == 1): prop nt_mad, over(urban newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
n_cat_loop
putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("rural urban") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop nt_mad, over(urban  )
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'
n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & nt_mad!=.): tab urban
matrix item_tot_n=e(ObsSub)'
matlist item_tot_n
putexcel B14 = matrix(item_tot_n), nfor(0)

* get Ns
quietly svy, subpop(if include==1 & nt_mad!=.): tab newregion urban, row
matrix item_n=e(ObsSub)
matlist item_n
putexcel B10 = matrix(item_n), nfor(0)

* Get Pearson test value
egen urban_pov = group(nt_mad urban ), label
svy, subpop(if include == 1): tab newregion urban_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

**Table ‎A-44: Proportion of Child MAD by Health Status (%)
**# ch_ari and ch_diar

svy, subpop(if include == 1 & ch_ari==1): prop nt_mad, over(ch_ari newregion)
matrix VP = e(b)'
matlist VP
matrix CI =r(table)'
matlist CI
* Call loop (assuming you have defined this loop elsewhere)
n_cat_loop

putexcel set "Child_Diet_Tables_final ANNEX.xlsx", sheet("health status (kids only)") modify
putexcel B3 = matrix(VPT), nfor(percent)

* Get Pearson test value
egen ari_pov = group(nt_mad ch_ari), label
svy, subpop(if include == 1): tab newregion ari_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

svy, subpop(if include == 1 & ch_diar==1): prop nt_mad, over(ch_diar newregion)
matrix VP = e(b)'
matlist VP

* Call loop (assuming you have defined this loop elsewhere)
n_cat_loop

putexcel B3 = matrix(VPT), nfor(percent)

* Get Pearson test value
egen diar_pov = group(nt_mad ch_diar), label
svy, subpop(if include == 1): tab newregion diar_pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

export delimited "${output}\child_diet_analysis.csv", replace 