/*******************************************************************************************************************************
Program: 				HR DATA cleaning.do
Purpose: 				Clean DHS raw data at the Household level and create variables that are necessary

Input Data: 			MDHR81FL.DTA (Madagascar: Standard DHS, 2021)
						MDGE81FL_DISTRICT.csv

Outputs:				hrdata_clean.dta 
						cluster_household_data.csv 
						region_household_data.csv

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/

use "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\USAID Programs (Cleaned)\0.Raw data\MDHR81FL.DTA", clear


gen wt=hv005/1000000

count



************************************************************
* CHECK VALUES of variables
************************************************************
** socio-economic: education for head
assert !mi(sh17_01) if hv101_01==1
tab sh17_01, m

** socio-economic: housing/location; categorical vars plus number of rooms
tab1 hv025 hv201 hv205 hv213 hv206 hv226 hv216, m

** socio-economic: assets; binary vars plus amount of land
summ hv207 hv208 hv243a hv221 hv243e hv209 hv210 hv243c hv211 hv212 hv243d hv244 hv245 hv246
assert !mi(hv245) if hv244==1 

** socio-economic: wealth/poverty indicators
summ hv012 hv270 hv271
tab1 hv012 hv270, m

** socio-demographic: size, HH head sex, HH head age
tab1 hv219 hv220, m

** socio-demographic and health: nets
summ hv103* hml16_* hml12* // slept last night, age in months for kids, type of net

** possible other indicators of interest
summ hv102* hv105* hv111* hv112* hv113* hv114* hv219* 


*keep hv025 hv201 hv205 hv213 hv206 hv226 hv216 hv207 hv208 hv243a hv221 hv243e hv209 hv210 hv243c hv211 hv212 hv243d hv244 hv245 hv246 hv012 hv270 hv102 hv105 hv111 hv112 hv113 hv114 hv219 hv005 hv012 hv219 hv220 hv103 hml16 hml12 hv101_01, clear

************************************************************
* CONSTRUCT VARIABLES
************************************************************

label define noyes 0 "No" 1 "Yes", replace

* key outcome variables

** poverty: living in bottom quintile according to wealth index
gen poverty20=0 if hv270!=.
replace poverty20=1 if hv270==1
label var poverty20 "Household poverty: in bottom quintile by wealth index"

** alternative measure: living in bottom 40 percent 
gen poverty40=0 if hv270!=.
replace poverty40=1 if hv270==1 | hv270==2
label var poverty40 "Household poverty: in bottom 2 quintiles by wealth index"


* socio-economic correlates

** socio-economic: education for head
clonevar education=sh17_01

*** create dummies for use in tables
local educ "no_education incompl_primary primary incompl_sec1 sec1 incompl_sec2 sec2 higher dk"
local educ_descrip "No_education Incomplete_Primary Completed_Primary Incomplete_Secondary1 Completed_Secondary1 Incomplete_Secondary2 Completed_Secondary2 Higher_Education Dont_Know"
local code "0 1 2 3 4 5 6 7 8"
forvalues i = 1/9 {
	local f: word `i' of `educ'
	local d: word `i' of `educ_descrip'
	local c: word `i' of `code'
	gen educ_`f' = cond(education == .,.,cond(education==`c' & hv101_01==1, 1, 0))
	label variable educ_`f' "Household head education level is `d'"
	label values educ_`f' noyes
}

*** check constructed variables
tab1 educ_*, m

** socio-economic: housing/location; categorical vars plus number of rooms
tab1 hv025 hv201 hv205 hv213 hv215 hv206 hv226 hv216, m

*** urban
gen urban=hv025
recode urban 2=0
label variable urban "Household lives in urban location"

*** water source
recode hv201 13 = 14 14 = 13, gen (wtr_source)

label define lab_wtr_source 	11   "piped into dwelling"				///
									12	 "piped to yard/plot" 				///
									13	 "public tap/standpipe" 			///
									14	 "piped to neighbor"				///
									15	 "piped outside of yard/lot" 		///
									21	 "tube well or borehole" 			///
									30	 "well - protection unspecified" 	///
									31	 "protected well" 					///
									32	 "unprotected well"					///
									40	 "spring - protection unspecified" 	///
									41	 "protected spring" 				///
									42	 "unprotected spring"				///
									43	 "surface water (river/dam/lake/pond/stream/canal/irrigation channel)" ///
									51	 "rainwater"						///
									61	 "tanker truck"						///
									62	 "cart with small tank, cistern, drums/cans" ///
									65	 "purchased water"					///
									71	 "bottled water"					///
									72	 "purified water, filtration plant" ///
									73	 "sachet water"					///
									96	 "other"

label values wtr_source lab_wtr_source
label var wtr_source "Source of drinking water"


*** create dummy for improved water source
recode wtr_source (11/15 21 31 41 51 61/73 = 1 "improved water") (30 32 40 42 43 96 = 0 "unimproved/surface water") (99=99 "missing"), gen(water_improve)
label var water_improve "Improved Water Source"
tab water_improve, m

*** type of toilet
gen sani_type = hv205
recode sani_type . = 99

label define lab_sani_type	11	 "flush - to piped sewer system" ///
								12	 "flush - to septic tank"		///
								13	 "flush - to pit latrine"		///
								14	 "flush - to somewhere else"	///
								15	 "flush - don't know where/unspecified"			///
								21	 "pit latrine - ventilated improved pit (vip)"	///
								22	 "pit latrine - with slab"		///
								23	 "pit latrine - without slab / open pit" 		///
								31	 "no facility/bush/field/river/sea/lake" 		///
								41	 "composting toilet"			///
								42	 "bucket toilet"				///
								43	 "hanging toilet/latrine"		///
								51	 "other improved"				///
								96	 "other"						///
								99 	 "missing"
label values sani_type lab_sani_type
label var sani_type "Type of sanitation"

*** impoved toilet
recode sani_type (11/13 15 21 22 41 51 = 1 "improved toilet") (14 23 42 43 96 = 2 "unimproved toilet") (31 = 3 "open defecation") (99=.), gen(sani_improve)

local toilet "improved unimproved open"
local toilet_descrip "improved_toilet unimproved_toilet open_defecation"
local code "1 2 3"
forvalues i = 1/3 {
	local f: word `i' of `toilet'
	local d: word `i' of `toilet_descrip'
	local c: word `i' of `code'
	gen toilet_`f' = cond(sani_improve == .,.,cond(sani_improve==`c', 1, 0))
	label variable toilet_`f' "Toilet type is `d'"
	label values toilet_`f' noyes
}

*** roof type: most common types seem to be thatch, metal, and tiles
gen roof_categ=hv215

recode roof_categ (12 = 1 "thatch palm leaf") (22 = 2 "palm bamboo") (31 = 3 "metal") (11 13/21 23/24 32/96 = 4 "other"), gen(roof_type)

local roof "thatchleaf palmbamb metal other"
local roof_descrip "thatch_palm_leaf palm_bamboo metal other"
local code "1 2 3 4"
forvalues i = 1/4 {
	local f: word `i' of `roof'
	local d: word `i' of `roof_descrip'
	local c: word `i' of `code'
	gen roof_`f' = cond(roof_type == .,.,cond(roof_type==`c', 1, 0))
	label variable roof_`f' "Roof type is `d'"
	label values roof_`f' noyes
}

*** floor material
gen floor_categ=hv213

recode floor_categ (11 = 1 "earth sand") (21 = 2 "wood planks") (22 = 3 "palm bamboo") (23 = 4 "mats") (32 = 5 "vinyl asphalt") (34 = 6 "cement") (12 31 33 35 96 = 7 "other"), gen(floor_type)

local floor "earthsand woodplanks palmbamb mats vinylasph cement other"
local floor_descrip "earth_sand wood_planks palm_bamboo mats vinyl_asphalt cement other"
local code "1 2 3 4 5 6 7"
forvalues i = 1/7 {
	local f: word `i' of `floor'
	local d: word `i' of `floor_descrip'
	local c: word `i' of `code'
	gen floor_`f' = cond(floor_type == .,.,cond(floor_type==`c', 1, 0))
	label variable floor_`f' "Floor type is `d'"
	label values floor_`f' noyes
}

tab1 floor_*, m

*** electricity: hv206
clonevar electricity = hv206

*** cooking fuel: hv226
gen cookfuel_categ=hv226

recode cookfuel_categ (7 = 1 "charcoal") (8 = 2 "wood") (9 = 3 "straw shrub") (1/6 10/96 = 4 "other"), gen(cookfuel_type)

local cookfuel "charcoal wood strawshrub other"
local cookfuel_descrip "charcoal wood straw_shrub_grass other"
local code "1 2 3 4"
forvalues i = 1/4 {
	local f: word `i' of `cookfuel'
	local d: word `i' of `cookfuel_descrip'
	local c: word `i' of `code'
	gen cookfuel_`f' = cond(cookfuel_type == .,.,cond(cookfuel_type==`c', 1, 0))
	label variable cookfuel_`f' "Cook fuel type is `d'"
	label values cookfuel_`f' noyes
}

tab1 cookfuel_*, m


*** number of rooms for sleeping: hv216
clonevar num_rooms_sleep = hv216

** socio-economic: assets; binary vars plus amount of land
summ hv207 hv208 hv243a hv221 hv243e hv209 hv210 hv243c hv211 hv212 hv243d hv244 hv245 hv246
clonevar radio = hv207
clonevar television = hv208
clonevar mobile_phone = hv243a
clonevar telephone = hv221
clonevar computer = hv243e
clonevar refrigerator = hv209
clonevar bicycle = hv210
clonevar animal_cart = hv243c
clonevar motorcyle = hv211
clonevar car_truck = hv212
clonevar boat = hv243d
clonevar own_agricland = hv244
gen hectares_agricland = hv245
clonevar own_livestock = hv246
clonevar own_bankaccount = hv247

* add additional variables for animals owned
** these variables are number owned but numbers are limited for all but poultry and zebus so create amount owned for those only

local anim "cows horses goats sheep poultry zebus ducks pigs"
local anim_descrip "cows_bulls horses_donkeys_mules goats sheep chicken_poultry zebus ducks_geese_turkey pigs"
local suff "b c d e f g h i"

forvalues i = 1/8 {
	local f: word `i' of `anim'
	local d: word `i' of `anim_descrip'
	local t: word `i' of `suff'
	
    gen own_`f'=0
	replace own_`f'=1 if(hv246`t'!=. & hv246`t'!=0)
	label variable own_`f' "Owns `d'"
}


clonevar numown_poultry = hv246f
clonevar numown_zebus = hv246g

bysort hv024: summ hv246f if inlist(hv024,25,51,52,53) & hv246f!=98 & hv246f!=0, d

* poultry have some values of 98: replace with median by region
replace numown_poultry=7 if numown_poultry==98 & hv024==25 
replace numown_poultry=4 if numown_poultry==98 & hv024==51 
replace numown_poultry=3 if numown_poultry==98 & hv024==52 
replace numown_poultry=4 if numown_poultry==98 & hv024==53 

* do same for zebus
bysort hv024: summ hv246g if inlist(hv024,25,51,52,53) & hv246g!=98 & hv246g!=0, d
replace numown_zebus=4 if numown_zebus==98 & hv024==25 
replace numown_zebus=2 if numown_zebus==98 & hv024==51 
replace numown_zebus=2 if numown_zebus==98 & hv024==52 
replace numown_zebus=5 if numown_zebus==98 & hv024==53 

* check for poultry outliers
bysort hv024: summ numown_poultry if inlist(hv024,25,51,52,53) & own_poultry==1, d

*** check for upper outliers
egen numpoultry_iqr = iqr(numown_poultry) if numown_poultry!=0
egen numpoultry_med = median(numown_poultry)if numown_poultry!=0
gen numpoultry_upperbound = numpoultry_med + ((3*numpoultry_iqr)/1.35)

replace numown_poultry=numpoultry_upperbound if numown_poultry>numpoultry_upperbound & numpoultry_upperbound<.

drop numpoultry_iqr-numpoultry_upperbound

* check for zebus outliers
bysort hv024: summ numown_zebus if inlist(hv024,25,51,52,53) & own_zebus==1, d

*** check for upper outliers
egen numzebus_iqr = iqr(numown_zebus) if numown_zebus!=0
egen numzebus_med = median(numown_zebus)if numown_zebus!=0
gen numzebus_upperbound = numzebus_med + ((3*numzebus_iqr)/1.35)

count if numown_zebus>numzebus_upperbound & numzebus_upperbound<.

replace numown_zebus=numzebus_upperbound if numown_zebus>numzebus_upperbound & numzebus_upperbound<.

drop numzebus_iqr-numzebus_upperbound

*** fix values for hectares of land
replace hectares_agricland=0 if(own_agricland==0)

bysort hv024: summ hectares_agricland if inlist(hv024,25,51,52,53) & own_agricland==1 & hectares_agricland!=998, d

replace hectares_agricland=10 if hectares_agricland==998

replace hectares_agricland=hectares_agricland/10 // original value was multiplied by 10 
label var hectares_agricland "Hectares of agric land owned by HH"

summ hectares_agricland

*** check for upper outliers
egen hectares_iqr = iqr(hectares_agricland) if hectares_agricland!=0
egen hectares_med = median(hectares_agricland)if hectares_agricland!=0
gen hectares_upperbound = hectares_med + ((3*hectares_iqr)/1.35)

replace hectares_agricland=hectares_upperbound if hectares_agricland>hectares_upperbound & hectares_upperbound<.

drop hectares_iqr-hectares_upperbound

** construct vars for socio-demographic: size, HH head sex, HH head age
gen hhsize=hv012
label var hhsize "Number of HH members"

gen hh_head_female=(hv219==2)
label var hh_head_female "HH head sex is female"

gen hh_head_age=hv220
label var hh_head_age "Age of household head"

** construct socio-demographic and health: nets
** check guide to stats
summ hv103* hml16_* hml12* // slept last night, age in months for kids, type of net

** construct indicator if any child under 5 in household slept under itn

local varnum "01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16 17 18 19 20 21 22"
forvalues i = 1/22 {
	local f: word `i' of `varnum'
	gen child_itn_`f' = 0 if hv103_`f'!=. & hml16_`f'!=. & hml12_`f'!=.
	replace child_itn_`f' = 1 if hv103_`f'==1 & hml16_`f'<5 & hml12_`f'<3
}

egen child_slept_itn=rowmax(child_itn_01-child_itn_22)
label var child_slept_itn "Any child in HH slept under ITN last night"

drop child_itn_*

** hhsize and sex of head already constructed above
summ hv105* hv111* hv112* hv113* hv114*

** age related vars: number of children under 5; dependency ratio
egen num_child_under5=anycount(hv105*), values(0/4)

** create dependency age groups: 0-14, 15-64, 65 plus
egen num_mbrs_14=anycount(hv105*), values(0/14)
egen num_mbrs_1564=anycount(hv105*), values(15/64)
egen num_mbrs_65=anycount(hv105*), values(65/97)

gen dependency_ratio=(num_mbrs_14+num_mbrs_65)/num_mbrs_1564
replace dependency_ratio=(num_mbrs_14+num_mbrs_65)/1 if dependency_ratio==.
summ dependency*

* handwashing with soap variable for GIS analysis
** focus on soap only, not water and soap
gen handwash_soap= 0 if inlist(hv230a,1,2)
replace handwash_soap=1 if hv232==1
label var handwash_soap "Place observed for handwashing with soap"	

* key location variables
clonevar cluster_number = hv001
clonevar region=hv024

* construct district vars from GIS file
tempfile beforecollapse
save `beforecollapse'


** Actual districts based on geospatial mapping of DHS clusters to districts
import delimited using "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\Raw data\MDGE81FL_DISTRICT.csv", clear
describe


* pullin district names
clonevar district_temp = pulse_adm2_en

clonevar cluster_number = dhsclust

keep district_temp cluster_number pulse_study

merge 1:m cluster_number using "`beforecollapse'"

encode district_temp, gen(district)

tab district, m

* save version collapsed to cluster level for GIS analysis
preserve
collapse (mean) hhsize hh_head_age hh_head_female num_child_under5 poverty20 handwash_soap water_improve numown_poultry numown_zebus (max) region district pulse_study  [pw=wt], by(cluster_number)




* keep as whole country, don't restrict to pulse_study==1
export delimited using "${clean}\cluster_household_data.csv", replace

restore

* regional level
preserve
collapse (mean) hhsize hh_head_age hh_head_female num_child_under5 poverty20 handwash_soap water_improve numown_poultry numown_zebus (max) pulse_study  [pw=wt], by(region)


* keep as whole country, don't restrict to pulse_study==1

keep hhsize poverty20 region pulse_study

export delimited using "${clean}\region_household_data.csv", replace

tab region pulse_study

restore

*Keep statement to try and reduce the output datasize 
keep wt  poverty20 poverty40 education urban wtr_source water_improve sani_type sani_improve roof_categ roof_type floor_categ floor_type electricity cookfuel_categ cookfuel_type num_rooms_sleep radio television mobile_phone telephone computer refrigerator bicycle animal_cart motorcyle car_truck boat own_agricland hectares_agricland own_livestock own_bankaccount own_* numown_poultry numown_zebus hhsize hh_head_female hh_head_age child_slept_itn dependency_ratio handwash_soap cluster_number region district pulse_study educ_* toilet_* roof_* floor_* cookfuel_* num_mbrs_14 num_mbrs_1564 num_mbrs_65 hhsize hh_head_age hh_head_female num_child_under5 poverty20 handwash_soap water_improve numown_poultry numown_zebus



* Save the new dataset:
save "${clean}\hrdata_clean.dta", replace
