/*******************************************************************************************************************************
Program: 				Household Analysis.do

Purpose: 				Descriptive Statistics for Household data, calculating proportions and confidence intervals, performing a Pearson test, and 
						exporting the processed and aggregated data to an Excel spreadsheet for the purpose of creating descriptive statistics reports on 
						household poverty patterns within specified regions and socioeconomic categories

Input Data:				hrdata_clean.dta (created in HR Data Cleaning.do)

Outputs:				Household tables_final.xlsx
						hrdata_clean.csv

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/

clear
capture log close
** SetUp
use "${clean}\hrdata_clean.dta", 

* general variables and statements
svyset hv021[pw=wt], strata(hv022) singleunit(centered)

g include = 0
replace include = 1 if inlist(region,25,51,52,53)

* re-organize values of region to create output in order: androy, anosy, atsimo andrefana, atsimo atsinanana
tab region

recode region (52=1 "Androy") (53=2 "Anosy") (51=3 "AtsimoAndrefana") (25=4 "AtismoAtsinanana"), pre(new)label(newreg)

tab region


********************************
********************************
*Below is the code for min stunting
********************************
********************************

**# n_cat_loop
* write a program to implement the numerical loop
cap prog drop n_cat_loop
prog def n_cat_loop
  * 8 come from 4 regions * 2 poverty levels 
scalar n_cat = rowsof(VP)/8
local start = n_cat * 4 +1
forvalues j = 1/`=n_cat' {
	local end = `start'+3
	display `j' " start:"`start'
	display `j' " end:"`end'
	matselrc VP VP`j', r(`start'/`end')
	local start = `start' + 4 
}
mat VPT = VP1
local j = 2
 while (`j' <= `=n_cat') {
	mat VPT = (VPT,VP`j')
	local j = `j' + 1
}
matlist VPT
end

cap prog drop n_cat_tot_loop
prog def n_cat_tot_loop
  * 2 come from 1 total * 2 outcome levels 
scalar n_cattot = rowsof(VP)/2
local starttot = n_cattot * 1 +1 // adjusted from 3 to 1?
forvalues j = 1/`=n_cattot' {
	local endtot = `starttot' // adjusted from +3 to +0
	display `j' " starttot:"`starttot'
	display `j' " endtot:"`endtot'
	matselrc VP VP`j', r(`starttot'/`endtot') 
	local starttot = `starttot' + 1 // adjusted from 4 to 1
}
mat VPT = VP1
local j = 2
 while (`j' <= `=n_cattot') {
	mat VPT = (VPT,VP`j')
	local j = `j' + 1
}
matlist VPT
end




**# Overall result without disaggregation
**Table ‎A-2: Poverty Levels by Region (%)
svy, subpop(if include == 1): prop poverty20, over(newregion)
* ereturn list (show all element options)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI


* call loop
n_cat_loop

putexcel set "Household tables_final.xlsx", sheet("Key outcome poverty") modify
putexcel B3 = matrix(VPT), nfor(percent)


* add overall result
svy, subpop(if include == 1): prop poverty20
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop

putexcel B7 = matrix(VPT), nfor(percent)


** overall Ns: use mean rather than tab here b/c no disaggregation
quietly svy, subpop(if include==1 & poverty20!=.): mean poverty20
matrix pov_tot_n=e(N_sub)
putexcel B14 = matrix(pov_tot_n), nfor(0)


** get Pearson test value
svy, subpop(if include==1): tab newregion poverty20, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

** CIs for regional results
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

* get Ns
svy, subpop(if include==1 & poverty20!=.): tab newregion  
matrix pov_n=e(ObsSub)
matlist pov_n
putexcel B10 = matrix(pov_n), nfor(0)


** CIs for pooled results
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)



**Table A-1: Households living in poverty by region and gender of head (%)

svy, subpop(if include == 1): prop poverty20, over(hh_head_female newregion)
* ereturn list (show all element options)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'

* call loop
n_cat_loop

putexcel set "Household tables_final.xlsx", sheet("Table 1 headship") modify
putexcel B3 = matrix(VPT), nfor(percent)

* add overall result
svy, subpop(if include == 1): prop poverty20, over(hh_head_female)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab hh_head_female
matrix fem_tot_n=e(ObsSub)'
matlist fem_tot_n
putexcel B14 = matrix(fem_tot_n), nfor(0)



* get Pearson test value
egen femalepov=group(poverty20 hh_head_female), label
svy, subpop(if include==1): tab newregion femalepov, row
putexcel B8 = `e(p_Pear)'
putexcel B8 , overwr nfor(0.000)

** CIs for regional results

* confidence intervals
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion hh_head_female, row
matrix fem_n=e(ObsSub)
matlist fem_n
putexcel B10 = matrix(fem_n), nfor(0)

** add CIs for pooled results
*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

**Table ‎A-3: Proportion of Households Living in Poverty by Household Size (%)

** create categories for hhsize
recode hhsize (6/96 = 6 "6 plus"), gen(hhsize_cat)
recode hhsize (1/2 = 2 "2 or less") (6/96 = 6 "6 plus"), gen(hhsize_cat2)

svy, subpop(if include == 1 ): prop poverty20, over(hhsize_cat2 newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("Table 2 hh size") modify
putexcel B3 = matrix(VPT), nfor(percent)

* add overall result
svy, subpop(if include == 1): prop poverty20, over(hhsize_cat2)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab hhsize_cat2
matrix hhsize_tot_n=e(ObsSub)'
matlist hhsize_tot_n
putexcel B14 = matrix(hhsize_tot_n), nfor(0)

* get Pearson test value
egen sizepov=group(poverty20 hhsize_cat2), label
svy, subpop(if include==1): tab newregion sizepov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)


* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion hhsize_cat2, row
matrix hhsize_n=e(ObsSub)
matlist hhsize_n
putexcel B10 = matrix(hhsize_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)


**Table ‎A-4: Proportion of Households Living in Poverty by Age of Household Head (%)
** create categories for hhh age
recode hv220 (1/19 = 1 "19 or younger") (20/34 = 2 "20-34") (35/49 = 3 "35-49") (50/100 = 4 "50 plus"), gen(hhhage_cat)


svy, subpop(if include == 1 ): prop poverty20, over(hhhage_cat newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("T3 head age") modify
putexcel B3 = matrix(VPT), nfor(percent)

*add overall result
svy, subpop(if include == 1): prop poverty20, over(hhhage_cat)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab hhhage_cat
matrix hhage_tot_n=e(ObsSub)'
matlist hhage_tot_n
putexcel B14 = matrix(hhage_tot_n), nfor(0)

* get Pearson test value
egen agepov=group(poverty20 hhhage_cat), label
svy, subpop(if include==1): tab newregion agepov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)


* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion hhhage_cat, row
matrix hhage_n=e(ObsSub)
matlist hhage_n
putexcel B10 = matrix(hhage_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("T3 head age") modify
putexcel B16 = matrix(VPT), nfor(percent)
*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("T3 head age") modify
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel set "Household tables_final.xlsx", sheet("T3 head age") modify
putexcel B20 = matrix(VPT), nfor(percent)
*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel set "Household tables_final.xlsx", sheet("T3 head age") modify
putexcel B26 = matrix(VPT), nfor(percent)







**Table ‎A-5: Proportion of Households Living in Poverty by Education of Household Head (%)
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion education, row
matrix hheduc_n=e(ObsSub)
matlist hheduc_n

recode education (0=0 "None") (1=1 "Incomplete Primary") (2/7 = 3 "Complete primary or higher"), gen(hheduc_cat)



svy, subpop(if include == 1 ): prop poverty20, over(hheduc_cat newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]

putexcel set "Household tables_final.xlsx", sheet("T4 head educ") modify
putexcel B3 = matrix(VPT), nfor(percent)

* add overall result
svy, subpop(if include == 1): prop poverty20, over(hheduc_cat)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
* since we want to drop Don't Know which is the last option, take a subset
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab hheduc_cat
matrix hheduc_tot_n=e(ObsSub)'
matrix hheduc_tot_n = hheduc_tot_n[1..rowsof(hheduc_tot_n),1..(colsof(hheduc_tot_n)-1)]
matlist hheduc_tot_n
putexcel B14 = matrix(hheduc_tot_n), nfor(0)


* get Pearson test value
egen educpov=group(poverty20 hheduc_cat), label
svy, subpop(if include==1): tab newregion educpov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)


* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion hheduc_cat, row
matrix hheduc_n=e(ObsSub)
matrix hheduc_n = hheduc_n[1..rowsof(hheduc_n),1..(colsof(hheduc_n)-1)]
matlist hheduc_n
putexcel B10 = matrix(hheduc_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
matrix VPT = VPT[1..rowsof(VPT),1..(colsof(VPT)-1)]
putexcel B26 = matrix(VPT), nfor(percent)



**Table ‎A-6: Proportion of Households Living in Poverty by Number of Children Under 5 (%)
recode hv014 (4/12 = 4 "4 plus"), gen(childu5)

svy, subpop(if include == 1 ): prop poverty20, over(childu5 newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("T5 children under 5") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(childu5)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab childu5
matrix childu5_tot_n=e(ObsSub)'
matlist childu5_tot_n
putexcel B14 = matrix(childu5_tot_n), nfor(0)


* get Pearson test value
egen u5pov=group(poverty20 childu5), label
svy, subpop(if include==1): tab newregion u5pov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion childu5, row
matrix childu5_n=e(ObsSub)
matlist childu5_n
putexcel B10 = matrix(childu5_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)





**Table ‎A-7: Proportion of Households Living in Poverty by Number of Dependents (0-14, 65+) (%)
gen num_mbrs_dpndt=num_mbrs_14+num_mbrs_65
recode num_mbrs_dpndt (4/14 = 4 "4 plus"), gen(num_mbrs)

svy, subpop(if include == 1 ): prop poverty20, over(num_mbrs newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("T6 dependency") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(num_mbrs)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab num_mbrs
matrix num_mbrs_tot_n=e(ObsSub)'
matlist num_mbrs_tot_n
putexcel B14 = matrix(num_mbrs_tot_n), nfor(0)


* get Pearson test value
egen mbrspov=group(poverty20 num_mbrs), label
svy, subpop(if include==1): tab newregion mbrspov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion num_mbrs, row
matrix num_mbrs_n=e(ObsSub)
matlist num_mbrs_n
putexcel B10 = matrix(num_mbrs_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)



**Table ‎A-8: Proportion of Households Living in Poverty by Household Possessions (%)
**# Radio

svy, subpop(if include == 1 & radio == 1): prop poverty20, over(radio newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("household possessions") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & radio == 1): prop poverty20, over(radio)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab radio

matrix radio_tot_n=e(N_sub)
*matrix radio_tot_n=e(ObsSub)'
matlist radio_tot_n
putexcel B14 = matrix(radio_tot_n), nfor(0)


* get Pearson test value
egen radpov=group(poverty20 radio), label
svy, subpop(if include==1): tab newregion radpov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & radio!=.): tab newregion  
matrix radio_n=e(ObsSub)
matlist radio_n

putexcel B10 = matrix(radio_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)



svy, subpop(if include == 1 & mobile_phone == 1): prop poverty20, over(mobile_phone newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("household possessions") modify
putexcel C3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & mobile_phone == 1): prop poverty20, over(mobile_phone)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel C7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab mobile_phone

matrix mobile_phone_tot_n=e(N_sub)
matlist mobile_phone_tot_n
putexcel C14 = matrix(mobile_phone_tot_n), nfor(0)

* get Pearson test value
egen phonepov=group(poverty20 mobile_phone), label
svy, subpop(if include==1): tab newregion phonepov, row
putexcel C8 = `e(p_Pear)'
putexcel C8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & mobile_phone!=.): tab newregion  
matrix mobile_phone_n=e(ObsSub)
matlist mobile_phone_n

putexcel C10 = matrix(mobile_phone_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel C16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel C22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel C20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel C26 = matrix(VPT), nfor(percent)



**# Bicycle
svy, subpop(if include == 1 & bicycle == 1): prop poverty20, over(bicycle newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("household possessions") modify
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & bicycle == 1): prop poverty20, over(bicycle)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel D7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab bicycle

matrix bicycle_tot_n=e(N_sub)
matlist bicycle_tot_n
putexcel D14 = matrix(bicycle_tot_n), nfor(0)

* get Pearson test value
egen bicpov=group(poverty20 bicycle), label
svy, subpop(if include==1): tab newregion bicpov, row
putexcel D8 = `e(p_Pear)'
putexcel D8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & bicycle!=.): tab newregion  
matrix bicycle_n=e(ObsSub)
matlist bicycle_n

putexcel D10 = matrix(bicycle_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT), nfor(percent)


**Table ‎A-9: Proportion of Households Living in Poverty by Water and Toilet (%)
**WATER
svy, subpop(if include == 1 ): prop poverty20, over(water_improve newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("housing water toilet") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(water_improve)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab water_improve
matrix water_improve_tot_n=e(ObsSub)'
matlist water_improve_tot_n
putexcel B14 = matrix(water_improve_tot_n), nfor(0)


* get Pearson test value
egen watpov=group(poverty20 water_improve), label
svy, subpop(if include==1): tab newregion watpov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion water_improve, row
matrix water_improve_n=e(ObsSub)
matlist water_improve_n
putexcel B10 = matrix(water_improve_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)


**toilet improve

svy, subpop(if include == 1 ): prop poverty20, over(sani_improve newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("housing water toilet") modify
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(sani_improve)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel D7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab sani_improve
matrix sani_improve_tot_n=e(ObsSub)'
matlist sani_improve_tot_n
putexcel D14 = matrix(sani_improve_tot_n), nfor(0)


* get Pearson test value
egen sanpov=group(poverty20 sani_improve), label
svy, subpop(if include==1): tab newregion sanpov, row
putexcel D8 = `e(p_Pear)'
putexcel D8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion sani_improve, row
matrix sani_improve_n=e(ObsSub)
matlist sani_improve_n
putexcel D10 = matrix(sani_improve_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT), nfor(percent)

**Table ‎A-10: Proportion of Households Living in Poverty by Roof (%)
svy, subpop(if include == 1 ): prop poverty20, over(roof_type newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("housing roof floor") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(roof_type)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab roof_type
matrix roof_type_tot_n=e(ObsSub)'
matlist roof_type_tot_n
putexcel B14 = matrix(roof_type_tot_n), nfor(0)


* get Pearson test value
egen roofpov=group(poverty20 roof_type), label
svy, subpop(if include==1): tab newregion roofpov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion roof_type, row
matrix roof_type_n=e(ObsSub)
matlist roof_type_n
putexcel B10 = matrix(roof_type_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

**Table ‎A-11: Proportion of Households Living in Poverty by Floor (%)
recode floor_type (2/3 = 7 "other"), gen(floor_cat)

svy, subpop(if include == 1 ): prop poverty20, over(floor_cat newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("housing roof floor") modify
putexcel F3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(floor_cat)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel F7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab floor_cat
matrix floor_cat_tot_n=e(ObsSub)'
matlist floor_cat_tot_n
putexcel F14 = matrix(floor_cat_tot_n), nfor(0)


* get Pearson test value
egen flrpov=group(poverty20 floor_cat), label
svy, subpop(if include==1): tab newregion flrpov, row
putexcel F8 = `e(p_Pear)'
putexcel F8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion floor_cat, row
matrix floor_cat_n=e(ObsSub)
matlist floor_cat_n
putexcel F10 = matrix(floor_cat_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel F16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel F22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel F20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel F26 = matrix(VPT), nfor(percent)



**Table ‎A-12/13: Proportion of Households Living in Poverty by Agricultural assets (%)
**# Any Livestock
svy, subpop(if include == 1 & own_livestock == 1): prop poverty20, over(own_livestock newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_livestock == 1): prop poverty20, over(own_livestock)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_livestock

matrix own_livestock_tot_n=e(N_sub)
*matrix own_livestock_tot_n=e(ObsSub)'
matlist own_livestock_tot_n
putexcel B14 = matrix(own_livestock_tot_n), nfor(0)


* get Pearson test value
egen livepov=group(poverty20 own_livestock), label
svy, subpop(if include==1): tab newregion livepov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_livestock!=.): tab newregion  
matrix own_livestock_n=e(ObsSub)
matlist own_livestock_n

putexcel B10 = matrix(own_livestock_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)


**# Cows
svy, subpop(if include == 1 & own_cows == 1): prop poverty20, over(own_cows newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel C3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_cows == 1): prop poverty20, over(own_cows)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel C7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_cows

matrix own_cows_tot_n=e(N_sub)
*matrix own_cows_tot_n=e(ObsSub)'
matlist own_cows_tot_n
putexcel C14 = matrix(own_cows_tot_n), nfor(0)


* get Pearson test value
egen cowpov=group(poverty20 own_cows), label
svy, subpop(if include==1): tab newregion cowpov, row
putexcel C8 = `e(p_Pear)'
putexcel C8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_cows!=.): tab newregion  
matrix own_cows_n=e(ObsSub)
matlist own_cows_n

putexcel C10 = matrix(own_cows_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel C16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel C22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel C20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel C26 = matrix(VPT), nfor(percent)


**# Cows
svy, subpop(if include == 1 & own_goats == 1): prop poverty20, over(own_goats newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel D3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_goats == 1): prop poverty20, over(own_goats)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel D7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_goats

matrix own_goats_tot_n=e(N_sub)
*matrix own_goats_tot_n=e(ObsSub)'
matlist own_goats_tot_n
putexcel D14 = matrix(own_goats_tot_n), nfor(0)


* get Pearson test value
egen gtpov=group(poverty20 own_goats), label
svy, subpop(if include==1): tab newregion gtpov, row
putexcel D8 = `e(p_Pear)'
putexcel D8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_goats!=.): tab newregion  
matrix own_goats_n=e(ObsSub)
matlist own_goats_n

putexcel D10 = matrix(own_goats_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel D16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel D22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel D20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel D26 = matrix(VPT), nfor(percent)



**# Sheep


svy, subpop(if include == 1 & own_sheep == 1): prop poverty20, over(own_sheep newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel E3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_sheep == 1): prop poverty20, over(own_sheep)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel E7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_sheep

matrix own_sheep_tot_n=e(N_sub)
*matrix own_sheep_tot_n=e(ObsSub)'
matlist own_sheep_tot_n
putexcel E14 = matrix(own_sheep_tot_n), nfor(0)


* get Pearson test value
egen shppov=group(poverty20 own_sheep), label
svy, subpop(if include==1): tab newregion shppov, row
putexcel E8 = `e(p_Pear)'
putexcel E8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_sheep!=.): tab newregion  
matrix own_sheep_n=e(ObsSub)
matlist own_sheep_n

putexcel E10 = matrix(own_sheep_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel E16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel E22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel E20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel E26 = matrix(VPT), nfor(percent)


**# Poultry
svy, subpop(if include == 1 & own_poultry == 1): prop poverty20, over(own_poultry newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel F3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_poultry == 1): prop poverty20, over(own_poultry)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel F7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_poultry

matrix own_poultry_tot_n=e(N_sub)
*matrix own_poultry_tot_n=e(ObsSub)'
matlist own_poultry_tot_n
putexcel F14 = matrix(own_poultry_tot_n), nfor(0)


* get Pearson test value
egen pltpov=group(poverty20 own_poultry), label
svy, subpop(if include==1): tab newregion pltpov, row
putexcel F8 = `e(p_Pear)'
putexcel F8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_poultry!=.): tab newregion  
matrix own_poultry_n=e(ObsSub)
matlist own_poultry_n

putexcel F10 = matrix(own_poultry_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel F16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel F22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel F20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel F26 = matrix(VPT), nfor(percent)


**# Zebus
svy, subpop(if include == 1 & own_zebus == 1): prop poverty20, over(own_zebus newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel G3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_zebus == 1): prop poverty20, over(own_zebus)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel G7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_zebus

matrix own_zebus_tot_n=e(N_sub)
matlist own_zebus_tot_n
putexcel G14 = matrix(own_zebus_tot_n), nfor(0)


* get Pearson test value
egen zbpov=group(poverty20 own_zebus), label
svy, subpop(if include==1): tab newregion zbpov, row
putexcel G8 = `e(p_Pear)'
putexcel G8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_zebus!=.): tab newregion  
matrix own_zebus_n=e(ObsSub)
matlist own_zebus_n

putexcel G10 = matrix(own_zebus_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel G16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel G22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel G20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel G26 = matrix(VPT), nfor(percent)


**# Ducks
* the own_ducks variable is for ducks, geese, and turkeys
svy, subpop(if include == 1 & own_ducks == 1): prop poverty20, over(own_ducks newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel H3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_ducks == 1): prop poverty20, over(own_ducks)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel H7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_ducks

matrix own_ducks_tot_n=e(N_sub)
matlist own_ducks_tot_n
putexcel H14 = matrix(own_ducks_tot_n), nfor(0)


* get Pearson test value
egen dkpov=group(poverty20 own_ducks), label
svy, subpop(if include==1): tab newregion dkpov, row
putexcel H8 = `e(p_Pear)'
putexcel H8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_ducks!=.): tab newregion  
matrix own_ducks_n=e(ObsSub)
matlist own_ducks_n

putexcel H10 = matrix(own_ducks_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel H16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel H22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel H20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel H26 = matrix(VPT), nfor(percent)

**# Pigs

svy, subpop(if include == 1 & own_pigs == 1): prop poverty20, over(own_pigs newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel I3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_pigs == 1): prop poverty20, over(own_pigs)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel I7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_pigs

matrix own_pigs_tot_n=e(N_sub)
matlist own_pigs_tot_n
putexcel I14 = matrix(own_pigs_tot_n), nfor(0)


* get Pearson test value
egen pgpov=group(poverty20 own_pigs), label
svy, subpop(if include==1): tab newregion pgpov, row
putexcel I8 = `e(p_Pear)'
putexcel I8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_pigs!=.): tab newregion  
matrix own_pigs_n=e(ObsSub)
matlist own_pigs_n

putexcel I10 = matrix(own_pigs_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel I16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel I22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel I20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel I26 = matrix(VPT), nfor(percent)




**# Animal cart
svy, subpop(if include == 1 & animal_cart == 1): prop poverty20, over(animal_cart newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel J3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & animal_cart == 1): prop poverty20, over(animal_cart)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel J7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab animal_cart

matrix animal_cart_tot_n=e(N_sub)
matlist animal_cart_tot_n
putexcel J14 = matrix(animal_cart_tot_n), nfor(0)


* get Pearson test value
egen acpov=group(poverty20 animal_cart), label
svy, subpop(if include==1): tab newregion acpov, row
putexcel J8 = `e(p_Pear)'
putexcel J8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & animal_cart!=.): tab newregion  
matrix animal_cart_n=e(ObsSub)
matlist animal_cart_n

putexcel J10 = matrix(animal_cart_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel J16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel J22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel J20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel J26 = matrix(VPT), nfor(percent)


**# Land
svy, subpop(if include == 1 & own_agricland == 1): prop poverty20, over(own_agricland newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("agricultural assets") modify
putexcel K3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1 & own_agricland == 1): prop poverty20, over(own_agricland)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel K7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab own_agricland

matrix own_agricland_tot_n=e(N_sub)
*matrix own_agricland_tot_n=e(ObsSub)'
matlist own_agricland_tot_n
putexcel K14 = matrix(own_agricland_tot_n), nfor(0)


* get Pearson test value
egen aglndpov=group(poverty20 own_agricland), label
svy, subpop(if include==1): tab newregion aglndpov, row
putexcel K8 = `e(p_Pear)'
putexcel K8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=. & own_agricland!=.): tab newregion  
matrix own_agricland_n=e(ObsSub)
matlist own_agricland_n

putexcel K10 = matrix(own_agricland_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel K16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel K22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel K20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel K26 = matrix(VPT), nfor(percent)




**Table ‎A-14: Proportion of Households Living in Poverty by Rural/Urban Location (%)
svy, subpop(if include == 1 ): prop poverty20, over(urban newregion)
matrix VP=e(b)'
matlist VP
matrix CI =r(table)'
matlist CI

n_cat_loop
putexcel set "Household tables_final.xlsx", sheet("rural urban") modify
putexcel B3 = matrix(VPT), nfor(percent)

* overall result
svy, subpop(if include == 1): prop poverty20, over(urban)
matrix VP=e(b)'
matlist VP
matrix CI_tot =r(table)'

n_cat_tot_loop
putexcel B7 = matrix(VPT), nfor(percent)

** overall Ns
svy, subpop(if include==1 & poverty20!=.): tab urban
matrix urban_tot_n=e(ObsSub)'
matlist urban_tot_n
putexcel B14 = matrix(urban_tot_n), nfor(0)


* get Pearson test value
egen urbpov=group(poverty20 urban), label
svy, subpop(if include==1): tab newregion urbpov, row
putexcel B8 = `e(p_Pear)'
putexcel B8, overwr nfor(0.000)

* get Ns
quietly svy, subpop(if include==1 & poverty20!=.): tab newregion urban, row
matrix urban_n=e(ObsSub)
matlist urban_n
putexcel B10 = matrix(urban_n), nfor(0)

* confidence intervals for regional values
*lower
mat VP = CI[1..rowsof(CI), 5]
n_cat_loop
putexcel B16 = matrix(VPT), nfor(percent)

*upper
mat VP = CI[1..rowsof(CI), 6]
n_cat_loop
putexcel B22 = matrix(VPT), nfor(percent)


** add CIs for pooled results

*lower
matlist CI_tot
mat VP = CI_tot[1..rowsof(CI_tot), 5]
n_cat_tot_loop
putexcel B20 = matrix(VPT), nfor(percent)

*upper
mat VP = CI_tot[1..rowsof(CI_tot), 6]
n_cat_tot_loop
putexcel B26 = matrix(VPT), nfor(percent)

export delimited "${output}\hrdata_clean.csv", replace 