/*******************************************************************************************************************************
Program: 				IR DATA cleaning.do
Purpose: 				Clean DHS raw data at the Individual level and create variables that are necessary

Input Data: 			MDIR81FL.DTA (Madagascar: Standard DHS, 2021)
						MDGE81FL_DISTRICT.csv

Outputs:				irdata_clean.dta 

Author: 				Anthony Leegwater, Eugene Lee
*******************************************************************************************************************************/
* for development and debugging: connect directly
use "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\USAID Programs (Cleaned)\0.Raw data\MDIR81FL.DTA", clear

count


************************************************************
* CHECK VALUES of variables
************************************************************

* malnutrition

summ v208 v213 b19_01 v438 v445
tab1 v208 v213, m


* socio-economic: Educational attainment and literacy
summ v106 v155 v731 v717 v170
tab1 v106 v155 v731 v717 v170, m


************************************************************
* CONSTRUCT VARIABLES
************************************************************
label define noyes 0 "No" 1 "Yes", replace


** Calculation for weight also used throughout program
gen wt=v005/1000000

** create key location variables
* key location variables
clonevar cluster_number = v001
clonevar region=v024

* construct district vars from GIS file

tempfile beforecollapse
save `beforecollapse'


** Actual districts based on geospatial mapping of DHS clusters to districts
import delimited using "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\Raw data\MDGE81FL_DISTRICT.csv", clear
describe


* pullin district names
clonevar district_temp = pulse_adm2_en

clonevar cluster_number = dhsclust

keep district_temp cluster_number pulse_study

merge 1:m cluster_number using "`beforecollapse'"

encode district_temp, gen(district)

tab district, m

* variables for geospatial analysis related to graduation criteria

** Decision-making for family decisions

***Decides on all three: health, purchases, and visits  either alone or jointly with partner
gen we_decide_all= inlist(v743a,1,2) & inlist(v743b,1,2) & inlist(v743d,1,2) if v502==1
label values we_decide_all yesno
label var we_decide_all "Decides on all three: health, purchases, and visits  either alone or jointly with partner"



** Decision-making for family planning

//Decision to use among users
gen fp_decyes_wmn=0 if v632!=.
replace fp_decyes_wmn = . if (v502!=1 | v213!=0 | v312==0)
replace fp_decyes_wmn = 1 if v632==1 | v632==3
label var fp_decyes_wmn "Decides on family planning among users alone or jointly"


//Decision to not use among non users
gen fp_decno_wmn=0 if v632a!=.
replace fp_decno_wmn = . if (v502!=1 | v213!=0 | v312!=0)
replace fp_decno_wmn = 1 if v632a==1 | v632a==3
label var fp_decno_wmn "Decides on not using family planning alone or jointly"


//ANC by type of provider

gen period=60
gen age=b19_01

	gen rh_anc_pv = 6 if m2a_1! = .
	replace rh_anc_pv 	= 4 	if m2f_1 == 1 | m2g_1 == 1 | m2h_1 == 1 | m2i_1 == 1 | m2j_1 == 1 | m2k_1 == 1 | m2l_1 == 1 | m2m_1 == 1
	replace rh_anc_pv 	= 3 	if m2d_1 == 1 | m2e_1 == 1
	replace rh_anc_pv 	= 2 	if m2b_1 == 1 | m2c_1 == 1  // added midwives for Madag
	replace rh_anc_pv 	= 1 	if m2a_1 == 1
	replace rh_anc_pv 	= 9 	if m2a_1 == 9
	replace rh_anc_pv	= .		if age>=period
	
	label define rh_anc_pv ///
	1 "Doctor" 		///
	2 "Nurse/midwife"	///
	3 "Other health worker" ///
	4 "TBA/other/relative"		///
	9 "Missing" ///
	6 "No ANC" 
	label val rh_anc_pv rh_anc_pv
	label var rh_anc_pv "Person providing assistance during ANC"
	
//ANC by skilled provider
	recode rh_anc_pv (1/2 = 1 "Skilled provider") (3/9 = 0 "Unskilled/no one") , gen(anc_pvskill)
	replace anc_pvskill = . if age>=period
	label var anc_pvskill "Skilled assistance during ANC"



gen fp_decno_nonuser = v632a
replace fp_decno_nonuser = . if (v502!=1 | v213!=0 | v312!=0)
label values fp_decno_nonuser V632
label var fp_decno_nonuser "Who makes decision not to use family planning among non-users"


** women occupation
recode v717 (0=1 "Not working") (4/5=2 "Agriculture") (3=3 "Sales") (9=4 "Unskilled manual" ) (1/2 6/8 10 96=5 "Other"), gen(woman_occup)


*** create dummies for use in tables
local occup "not_work agric sales unskill other"
local occup_descrip "not_working agriculture sales unskilled_manual other"
local code "1 2 3 4 5"
forvalues i = 1/5 {
	local f: word `i' of `occup'
	local d: word `i' of `occup_descrip'
	local c: word `i' of `code'
	gen wmn_occup_`f' = cond(woman_occup == .,.,cond(woman_occup==`c', 1, 0))
	label variable wmn_occup_`f' "Woman occupation is `d'"
	label values wmn_occup_`f' noyes
}


*Keep statement to reduce the datafile size:
keep v208 v213 b19_01 v438 v445 v106 v155 v731 v717 v170 wt cluster_number region district_temp pulse_study we_decide_all fp_decyes_wmn fp_decno_wmn rh_anc_pv anc_pvskill fp_decno_nonuser woman_occup wmn_occup_*


* Save the new dataset:
save "${clean}\irdata_clean.dta", replace


