/*******************************************************************************************************************************
Program: 				KR DATA cleaning.do
Purpose: 				Clean DHS raw data at the Child level and create variables that are necessary

Input Data: 			MDKR81FL.DTA (Madagascar: Standard DHS, 2021)

Outputs:				krdata_clean.dta

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/

use "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\USAID Programs (Cleaned)\0.Raw data\MDKR81FL.dta" , clear

count

************************************************************
* CHECK VALUES of variables
************************************************************

**Socio-demographic and health: ARI
summ b5 b9 b19 m4 v410 v411 v411a v412a v412c v413 v414e v414f v414g v414h v414i v414j v414k v414l v414m v414n v414o v414p v414s v414v v469e v469f v469x m39

* **Socio-economic: Micronutrient Intake among Children
summ h33d h33m h33y h34 h42 h43 h80a v414g v414h v414i v414j v414k v414m v414n 

* indicators of interest:
summ m18 m19 

* health: diarrhea prevalance ;
summ h11 h31b h32c  

************************************************************
* CONSTRUCT VARIABLES
************************************************************
label define noyes 0 "No" 1 "Yes", replace

**Calculate Age for future used

gen age=b19


* construct child food access and dietary diversity
* children 6-23 months

//currently breastfed
gen nt_bf_curr= m4==95
label values nt_bf_curr yesno
label var nt_bf_curr "Currently breastfeeding - last-born under 2 years"

//breastfeeding status
	gen water=0
	gen liquids=0
	gen milk=0
	gen solids=0

	*Child is given water
	replace water=1 if (v409>=1 & v409<=7)
		   
	*Child given liquids
	foreach xvar of varlist v409a v410 v410a v412c v413*{
	replace liquids=1 if `xvar'>=1 & `xvar'<=7
	}

	*Given powder/tinned milk, formula, or fresh milk
	foreach xvar of varlist v411 v411a {
	replace milk=1 if `xvar'>=1 & `xvar'<=7
	}

	*Given any solid food
	foreach xvar of varlist v414* {
	replace solids=1 if `xvar'>=1 & `xvar'<=7
	}
	replace solids=1 if v412a==1 | v412b==1 | m39a==1
	gen nt_bf_status=1
	replace nt_bf_status=2 if water==1
	replace nt_bf_status=3 if liquids==1
	replace nt_bf_status=4 if milk==1
	replace nt_bf_status=5 if solids==1
	replace nt_bf_status=0 if nt_bf_curr==0
	label define bf_status 0"not bf" 1"exclusively bf" 2"bf & plain water" 3"bf & non-milk liquids" 4"bf & other milk" 5"bf & complemenatry foods"
	label values nt_bf_status bf_status
	label var nt_bf_status "Breastfeeding status for last-born child under 2 years"

//exclusively breastfed
recode nt_bf_status (1=1) (else=0) if age<6, gen(nt_ebf)
label values nt_ebf yesno
label var nt_ebf "Exclusively breastfed - last-born under 6 months"

//predominantly breastfeeding
recode nt_bf_status (1/3=1) (else=0) if age<6, gen(nt_predo_bf)
label values nt_predo_bf yesno
label var nt_predo_bf "Predominantly breastfed - last-born under 6 months"

//age appropriate breastfeeding
gen nt_ageapp_bf=0
replace nt_ageapp_bf=1 if nt_ebf==1
replace nt_ageapp_bf=1 if nt_bf_status==5 & inrange(age,6,23)
label values nt_ageapp_bf yesno
label var nt_ageapp_bf "Age-appropriately breastfed - last-born under 2 years"

//introduced to food
gen nt_food_bf = 0
replace nt_food_bf=1 if (v412a==1 | v412b==1 | m39a==1)
	foreach i in a b c d e f g h i j k l m n o p q r s t u v w {
	replace nt_food_bf=1 if v414`i'==1
	} 
replace nt_food_bf=. if !inrange(age,6,8)
label values nt_food_bf yesno
label var nt_food_bf "Introduced to solid, semi-solid, or soft foods - last-born 6-8 months"
	
//continuing breastfeeding at 1 year
gen nt_bf_cont_1yr= m4==95 if inrange(age,12,15)
label values nt_bf_cont_1yr yesno
label var nt_bf_cont_1yr "Continuing breastfeeding at 1 year (12-15 months) - last-born under 2 years"

//continuing breastfeeding at 2 years
gen nt_bf_cont_2yr= m4==95 if inrange(age,20,23)
label values nt_bf_cont_2yr yesno
label var nt_bf_cont_2yr "Continuing breastfeeding at 2 year (20-23 months) - last-born under 2 years"

*** Foods consumed ***

//Given formula
gen nt_formula= v411a==1
label values nt_formula yesno
label var nt_formula "Child given infant formula in day/night before survey - last-born under 2 years"

//Given other milk
gen nt_milk= v411==1
label values nt_milk yesno 
label var nt_milk "Child given other milk in day/night before survey- last-born under 2 years"

//Given other liquids
gen nt_liquids= v410==1 | v412c==1 | v413==1
label values nt_liquids yesno 
label var nt_liquids "Child given other liquids in day/night before survey- last-born under 2 years"

//Given fortified baby food
gen nt_bbyfood= v412a==1
label values nt_bbyfood yesno 
label var nt_bbyfood "Child given fortified baby food in day/night before survey- last-born under 2 years"

//Given grains
gen nt_grains= v412a==1 | v414e==1
label values nt_grains yesno 
label var nt_grains "Child given grains in day/night before survey- last-born under 2 years"

//Given Vit A rich foods
gen nt_vita= v414i==1 | v414j==1 | v414k==1
label values nt_vita yesno 
label var nt_vita "Child given vitamin A rich food in day/night before survey- last-born under 2 years"

//Given other fruits or vegetables
gen nt_frtveg= v414l==1
label values nt_frtveg yesno 
label var nt_frtveg "Child given other fruits or vegetables in day/night before survey- last-born under 2 years"

//Given roots and tubers
gen nt_root= v414f==1
label values nt_root yesno 
label var nt_root "Child given roots or tubers in day/night before survey- last-born under 2 years"

//Given nuts or legumes
gen nt_nuts= v414o==1
label values nt_nuts yesno 
label var nt_nuts "Child given legumes or nuts in day/night before survey- last-born under 2 years"

//Given meat, fish, shellfish, or poultry
gen nt_meatfish= v414h==1 | v414m==1 | v414n==1
label values nt_meatfish yesno 
label var nt_meatfish "Child given meat, fish, shellfish, or poultry in day/night before survey- "
	
//Given eggs
gen nt_eggs= v414g==1
label values nt_eggs yesno 
label var nt_eggs "Child given eggs in day/night before survey- last-born under 2 years"

//Given dairy
gen nt_dairy= v414p==1 | v414v==1 
label values nt_dairy yesno 
label var nt_dairy "Child given cheese, yogurt, or other milk products in day/night before survey- last-born under 2 years"

//Given other solid or semi-solid foods
gen nt_solids= nt_bbyfood==1 | nt_grains==1 | nt_vita==1 | nt_frtveg==1 | nt_root==1 | nt_nuts==1 | nt_meatfish==1 | nt_eggs==1 | nt_dairy==1 | v414s==1
label values nt_solids yesno 
label var nt_solids "Child given any solid or semisolid food in day/night before survey- last-born under 2 years"


*** Minimum feeding indicators ***

//Fed milk or milk products
gen totmilkf = 0
replace totmilkf=totmilkf + v469e if v469e<8
replace totmilkf=totmilkf + v469f if v469f<8
replace totmilkf=totmilkf + v469x if v469x<8
gen nt_fed_milk= ( totmilkf>=2 | m4==95) if inrange(age,6,23)
label values nt_fed_milk yesno
label var nt_fed_milk "Child given milk or milk products- last-born 6-23 months"

//Min dietary diversity
	* 8 food groups
	*1. breastmilk
	gen group1= m4==95

	*2. infant formula, milk other than breast milk, cheese or yogurt or other milk products
	gen group2= nt_formula==1 | nt_milk==1 | nt_dairy==1

	*3. foods made from grains, roots, tubers, and bananas/plantains, including porridge and fortified baby food from grains
	gen group3= nt_grains==1 | nt_root==1 | nt_bbyfood==1
	 
	*4. vitamin A-rich fruits and vegetables
	gen group4= nt_vita==1

	*5. other fruits and vegetables
	gen group5= nt_frtveg==1

	*6. eggs
	gen group6= nt_eggs==1

	*7. meat, poultry, fish, and shellfish (and organ meats)
	gen group7= nt_meatfish==1

	*8. legumes and nuts
	gen group8= nt_nuts==1

* add the food groups
egen foodsum = rsum(group1 group2 group3 group4 group5 group6 group7 group8) 
recode foodsum (1/4 .=0 "No") (5/8=1 "Yes"), gen(nt_mdd)
replace nt_mdd=. if age<6
label values nt_mdd yesno 
label var nt_mdd "Child with minimum dietary diversity, 5 out of 8 food groups- last-born 6-23 months"

/*older surveys are 4 out of 7 food groups, can use code below
egen foodsum = rsum(group2 group3 group4 group5 group6 group7 group8) 
recode foodsum (1/3 .=0 "No") (4/7=1 "Yes"), gen(nt_mdd)
*/

//Min meal frequency
gen feedings=totmilkf
replace feedings= feedings + m39 if m39>0 & m39<8
gen nt_mmf = (m4==95 & inrange(m39,2,7) & inrange(age,6,8)) | (m4==95 & inrange(m39,3,7) & inrange(age,9,23)) | (m4!=95 & feedings>=4 & inrange(age,6,23))
replace nt_mmf=. if age<6
label values nt_mmf yesno
label var nt_mmf "Child with minimum meal frequency- last-born 6-23 months"

//Min acceptable diet
egen foodsum2 = rsum(nt_grains nt_root nt_nuts nt_meatfish nt_vita nt_frtveg nt_eggs)
gen nt_mad = (m4==95 & nt_mdd==1 & nt_mmf==1) | (m4!=95 & foodsum2>=4 & nt_mmf==1 & totmilkf>=2)
replace nt_mad=. if age<6
label values nt_mad yesno
label var nt_mad "Child with minimum acceptable diet- last-born 6-23 months"


gen wt=v005/1000000
svyset v021[pw=wt], strata(v022) singleunit(centered)


* keep if under 24 months and living with mother
keep if b19 < 24 & b9 == 0
* and keep the last born of those.
* if caseid is the same as the prior case, then not the last born
keep if _n == 1 | caseid != caseid[_n-1]




**Micronutrient Intake among Children**

**Received multiple micronutrient powder
gen nt_ch_micro_mp= h80a==1 
replace nt_ch_micro_mp=. if !inrange(age,6,23) | b5==0
label values nt_ch_micro_mp noyes 
label var nt_ch_micro_mp "Children age 6-23 mos given multiple micronutrient powder"

**Received iron supplements
gen nt_ch_micro_iron= h42==1 
replace nt_ch_micro_iron=. if !inrange(age,6,59) | b5==0
label values nt_ch_micro_iron noyes 
label var nt_ch_micro_iron "Children age 6-59 mos given iron supplements"

**Received Vit. A supplements
recode h33m (98=.), gen(h33m2)
recode h33d (98=15), gen(h33d2)
recode h33y (9998=.), gen(h33y2)
gen nt_ch_micro_vas= h34==1 | (int((mdy(v006,v016,v007) - mdy(h33m2,h33d2,h33y2) )/30.4375) < 6)
replace nt_ch_micro_vas=. if !inrange(age,6,59) | b5==0
label values nt_ch_micro_vas noyes 
label var nt_ch_micro_vas "Children age 6-59 mos given Vit. A supplements"

**Received deworming medication
gen nt_ch_micro_dwm= h43==1
replace nt_ch_micro_dwm=. if !inrange(age,6,59) | b5==0
label values nt_ch_micro_dwm noyes 
label var nt_ch_micro_dwm "Children age 6-59 mos given deworming medication"

**Received therapeutic food
gen nt_ch_food_ther= h80b==1
replace nt_ch_food_ther=. if !inrange(age,6,35) | b5==0
label values nt_ch_food_ther noyes 
label var nt_ch_food_ther "Children age 6-35 mos given therapeutic food"

**Received supplemental food
gen nt_ch_food_supp= h80c==1
replace nt_ch_food_supp=. if !inrange(age,6,35) | b5==0
label values nt_ch_food_supp noyes 
label var nt_ch_food_supp "Children age 6-35 mos given supplemental food"


*** Education ***

**Highest level of education
gen rc_edu= v149
label values rc_edu V149
label var rc_edu "Highest level of schooling attended or completed"


**Literacy level
recode v155 (2=1 ) (1=2) (0=3) (3=4) (4=5), gen(rc_litr_cats)
replace rc_litr_cats = 0 if v106 == 3

* Define literacy levels and corresponding dummy variable names
local liter_var "liter_higher_sec liter_whole_sentence liter_part_sentence liter_cannot_read liter_no_card liter_blind"
local liter_levels "Higher_than_secondary_education Can_read_a_whole_sentence Can_read_part_of_a_sentence Cannot_read_at_all No_card_with_required_language Blind/visually_impaired"

* Loop through literacy levels and create dummy variables
local i 1
foreach liter_level in `liter_levels' {
    local liter_dummy : word `i' of `liter_var'
    gen `liter_dummy' = cond(rc_litr_cats == `i', 1, 0)
    label variable `liter_dummy' "`liter_level'"
    local i = `i' + 1

}
* Check constructed dummy variables
tab1 liter_*, m

**Socio-economic: Employment and occupation**

**women employed in past 12 months
recode v731 (0=0 "Not employed") (1 2/3=1 "Employed") (8=99 "missing"), gen(rc_empl)
label var rc_empl "Employment status in the last 12 months"
tab rc_empl, m

**diarrhea**
**ARI 
gen ch_ari=0
cap replace ch_ari=1 if h31b==1 & (h31c==1 | h31c==3)
replace ch_ari =. if b5==0


label var ch_ari "ARI symptoms in the 2 weeks before the survey"
	
**ARI care-seeking
gen ch_ari_care=0 if ch_ari==1
foreach c in a b c d e f g h i j k l m n o p q r s u v w x {
replace ch_ari_care=1 if ch_ari==1 & h32`c'==1
}

label var ch_ari_care "Advice or treatment sought for ARI symptoms"

gen ch_diar=0
replace ch_diar=1 if h11==1 | h11==2
replace ch_diar =. if b5==0
label var ch_diar "Diarrhea in the 2 weeks before the survey"

//Diarrhea treatment	
gen ch_diar_care=0 if ch_diar==1
foreach c in a b c d e f g h i j k l m n o p q r s u v w x {
replace ch_diar_care=1 if ch_diar==1 & h12`c'==1
}

************************************************************
* Save the new dataset:
************************************************************

*Keep statement to reduce the datafile size:

keep v001 v002 v137 v155 v717 b5 b9 b19 m4 v410 v411 v412 v413 v469e v469f v469x m39 h33d h33m h33y h34 h42 h43 h80a h80b h80c age nt_bf_curr nt_bf_status nt_ebf nt_predo_bf nt_ageapp_bf nt_food_bf nt_bf_cont_1yr nt_bf_cont_2yr nt_formula nt_milk nt_liquids nt_bbyfood nt_grains nt_vita nt_frtveg nt_root nt_nuts nt_meatfish nt_eggs nt_dairy nt_solids group1-group8 foodsum nt_mdd feedings nt_mmf nt_mad wt nt_ch_micro_mp nt_ch_micro_iron nt_ch_micro_vas nt_ch_micro_dwm nt_ch_food_ther nt_ch_food_supp rc_edu rc_litr_cats liter_* rc_empl ch_ari ch_ari_care ch_diar ch_diar_care caseid



* Save the new dataset:
save "${clean}\krdata_clean.dta", replace