/*******************************************************************************************************************************
Program: 				MR DATA cleaning.do
Purpose: 				Clean DHS raw data at the Men's level and create variables that are necessary

Input Data: 			MDMR81FL.DTA (Madagascar: Standard DHS, 2021)
						MDGE81FL_DISTRICT.csv

Outputs:				mrdata_clean.dta

Author: 				Anthony Leegwater, Eugene Lee, Sara Sokolinski
*******************************************************************************************************************************/
use "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\USAID Programs (Cleaned)\0.Raw data\MDMR81FL.DTA", clear

count

************************************************************
* CHECK VALUES of variables
************************************************************
* socio-economic: Employment and occupation
summ mv106 mv155 mv731 mv717 mv170
tab1 mv106 mv155 mv731 mv717 mv170, m

************************************************************
* CONSTRUCT VARIABLES
************************************************************
label define noyes 0 "No" 1 "Yes", replace

gen wt=mv005/1000000

* key location variables
clonevar cluster_number = mv001
clonevar region=mv024

* construct district vars from GIS file

tempfile beforecollapse
save `beforecollapse'


** Actual districts based on geospatial mapping of DHS clusters to districts
import delimited using "S:\projects\BP-LASER_PULSE_BHA_RFSA_IN_MAD\DHS data\Raw data\MDGE81FL_DISTRICT.csv", clear
describe


* pullin district names
clonevar district_temp = pulse_adm2_en

clonevar cluster_number = dhsclust


keep district_temp cluster_number pulse_study

merge 1:m cluster_number using "`beforecollapse'"

encode district_temp, gen(district)

tab district, m
**Head of household Literacy
**Literacy level

recode mv155 (2=1 ) (1=2) (0=3) (3=4) (4=5), gen(rc_litr_cats)
replace rc_litr_cats = 0 if mv106 == 3

* Define literacy levels and corresponding dummy variable names
local liter_var "liter_higher_sec liter_whole_sentence liter_part_sentence liter_cannot_read liter_no_card liter_blind"
local liter_levels "Higher_than_secondary_education Can_read_a_whole_sentence Can_read_part_of_a_sentence Cannot_read_at_all No_card_with_required_language Blind/visually_impaired"

* Loop through literacy levels and create dummy variables
local i 1
foreach liter_level in `liter_levels' {
    local liter_dummy : word `i' of `liter_var'
    gen `liter_dummy' = cond(rc_litr_cats == `i', 1, 0)
    label variable `liter_dummy' "`liter_level'"
    local i = `i' + 1

}
* Check constructed dummy variables
tab1 liter_*, m


**Literate 
gen rc_litr=0
replace rc_litr=1 if mv106==3 | mv155==1 | mv155==2	
label values rc_litr noyes
label var rc_litr "Literate - higher than secondary or can read part or whole sentence"


**Socio-economic: Employment and Occupation**

*** Employment ***

**Employment status
recode mv731 (0=0 "Not employed in last 12 months") (1=1 "Not currently working but was employed in last 12 months") (2/3=2 "Currently employed") (8=9 "Don't know/missing"), gen(rc_empl)
label var rc_empl "Employment status"

**Occupation
recode mv717 (0=1 "Not working") (4/5=2 "Agriculture") (3=3 "Sales") (9=4 "Unskilled manual" ) (1/2 6/8 10 96=5 "Other"), gen(man_occup)
label var man_occup "Men: occupation"

** create dummies for occupation
local occup "not_work agric sales unskill other"
local occup_descrip "not_working agriculture sales unskilled_manual other"
local code "1 2 3 4 5"
forvalues i = 1/5 {
	local f: word `i' of `occup'
	local d: word `i' of `occup_descrip'
	local c: word `i' of `code'
	gen mn_occup_`f' = cond(man_occup == .,.,cond(man_occup==`c', 1, 0))
	label variable mn_occup_`f' "Man occupation is `d'"
	label values mn_occup_`f' noyes
}



**Type of employer
cap gen rc_empl_type=mv719 if inlist(mv731,1,2,3)
cap label values rc_empl_type MV719
cap label var rc_empl_type "Type of employer among those employed in the past 12 months"

************************************************************
* Save the new dataset:
************************************************************
*Keep statement to reduce the datafile size:
keep mv106 mv155 mv731 mv717 mv170 wt cluster_number region district_temp pulse_study rc_litr_cats liter_higher_sec liter_whole_sentence liter_part_sentence liter_cannot_read liter_no_card liter_blind rc_litr rc_empl man_occup mn_occup_not_work mn_occup_agric mn_occup_sales mn_occup_unskill mn_occup_other rc_empl_type



save "${clean}\mrdata_clean.dta", replace