/*******************************************************************************************************************************
Program: 				RQ3.do

Purpose: 				 conducts and exports a series of region-specific Ordinary Least Squares (OLS) regression analyses using survey data to investigate the 
						relationship between poverty, household demographics, socio-economic characteristics, assets, child stunting, and child minimum acceptable diet 
						in a statistical software environment.

Input Data:				hrdata_clean.dta (created in HR Data Cleaning.do)
						child_Stunting_analysis.dta (created in Child_Analysis_Merged_Data.do)
						child_diet_analysis.dta (created in Child_Analysis_Merged_Data.do)					

Author: 				Anthony Leegwater, Sara Sokolinski
*******************************************************************************************************************************/


*** use cleaned data
use "${clean}\hrdata_clean.dta", clear

* general variables and statements
svyset hv021[pw=wt], strata(hv022) singleunit(centered)

g include = 0
replace include = 1 if inlist(region,25,51,52,53)

* re-organize values of region to create output in order: androy, anosy, atsimo andrefana, atsimo atsinanana
tab region

recode region (52=1 "Androy") (53=2 "Anosy") (51=3 "AtsimoAndrefana") (25=4 "AtismoAtsinanana"), pre(new)label(newreg)






**Table B-1: Additional Results for Research Question 3: Poverty 
* Poverty and households
gen num_mbrs_dpndt=num_mbrs_14+num_mbrs_65


foreach d of varlist hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' poverty20
			estimates store Pov`d'reg`i'
		}
		outreg2 [Pov`d'reg*] using Poverty_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile povHHdemo
save `povHHdemo', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in dependency_ratio num_mbrs_dpndt num_child_under5 hhsize hh_head_age hh_head_female  {
    use `"Poverty_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `povHHdemo'
    save `"`povHHdemo'"', replace
}

export excel using pov_HH_demo_consolidated.xlsx, replace

restore


describe educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban own_bankaccount, fullname


* poverty and socio-economic characteristics:  educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban own_bankaccount
foreach d of varlist educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban own_bankaccount {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' poverty20
			estimates store Pov`d'reg`i'
		}
		outreg2 [Pov`d'reg*] using Poverty_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile povHHsocio
save `povHHsocio', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in urban bicycle mobile_phone television radio num_rooms_sleep cookfuel_other cookfuel_strawshrub cookfuel_wood cookfuel_charcoal cookfuel_type cookfuel_categ electricity floor_other floor_cement floor_vinylasph floor_mats floor_palmbamb floor_woodplanks floor_earthsand floor_type floor_categ roof_other roof_metal roof_palmbamb roof_thatchleaf roof_type roof_categ toilet_open toilet_unimproved toilet_improved water_improve educ_dk educ_higher educ_sec2 educ_incompl_sec2 educ_sec1 educ_incompl_sec1 educ_primary educ_incompl_primary educ_no_education {
    use `"Poverty_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `povHHsocio'
    save `"`povHHsocio'"', replace
}

export excel using pov_HH_socio_consolidated.xlsx, replace

restore



* poverty and other assets: own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus
foreach d of varlist own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' poverty20
			estimates store Pov`d'reg`i'
		}
		outreg2 [Pov`d'reg*] using Poverty_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile povHHassets
save `povHHassets', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in numown_zebus numown_poultry own_pigs own_ducks own_zebus own_poultry own_sheep own_goats own_horses own_cows own_livestock hectares_agricland animal_cart own_agricland {
    use `"Poverty_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	
	if "`f'" != "own_livestock" {
		keep if _n==5
	}
	else {
		keep if _n==6
	}
	display `"Appending `f'"'
    append using `povHHassets'
    save `"`povHHassets'"', replace
}



export excel using pov_HH_assets_consolidated.xlsx, replace

restore

** drop stored estimates to avoid system limit later
estimates drop Pov*reg*


* CHILD LEVEL
* stunting and socio-demographics
use "${clean}\child_stunting_analysis.dta", clear

* set svy and some necessary vars
svyset hv021[pw=wt], strata(hv022) singleunit(centered)

g include = 0
replace include = 1 if inlist(region,25,51,52,53)

recode region (52=1 "Androy") (53=2 "Anosy") (51=3 "AtsimoAndrefana") (25=4 "AtismoAtsinanana"), pre(new)label(newreg)

gen num_mbrs_dpndt=num_mbrs_14+num_mbrs_65


** Table B-2: Additional Results for Research Question 3: Child Stunting
** all regions: household demo
foreach d of varlist hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio {
		svy, subpop(if include == 1): reg `d' nt_ch_stunt
		estimates store Stu`d'allreg
	
		outreg2 [Stu`d'allreg] using CH_stunt_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
}


* consolidate results

preserve

clear
tempfile stuntdemoallreg
save `stuntdemoallreg', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in dependency_ratio num_mbrs_dpndt num_child_under5 hhsize hh_head_age hh_head_female  {
    use `"CH_stunt_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `stuntdemoallreg'
    save `"`stuntdemoallreg'"', replace
}

export excel using stunt_demo_allreg_consolidated.xlsx, replace
estimates drop Stu*

restore



** by region: stunting and demo

foreach d of varlist hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_ch_stunt
			estimates store Stu`d'reg`i'
		}
		outreg2 [Stu`d'reg*] using CH_stunt_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}


* consolidate results

preserve

clear
tempfile stuntdemo
save `stuntdemo', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in dependency_ratio num_mbrs_dpndt num_child_under5 hhsize hh_head_age hh_head_female  {
    use `"CH_stunt_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `stuntdemo'
    save `"`stuntdemo'"', replace
}

export excel using stunt_demo_consolidated.xlsx, replace
estimates drop Stu*

restore


** all 4 regions: stunting and socio-economic:  educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban own_bankaccount
foreach d of varlist educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban {
		svy, subpop(if include == 1): reg `d' nt_ch_stunt
			estimates store Stu`d'all
		outreg2 [Stu`d'all] using CH_stunt_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
} 


* consolidate results
preserve

clear
tempfile stuntsocioallreg
save `stuntsocioallreg', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in urban bicycle mobile_phone television radio num_rooms_sleep cookfuel_other cookfuel_strawshrub cookfuel_wood cookfuel_charcoal electricity floor_other floor_cement floor_vinylasph floor_mats floor_palmbamb floor_woodplanks floor_earthsand roof_other roof_metal roof_palmbamb roof_thatchleaf toilet_open toilet_unimproved toilet_improved water_improve educ_dk educ_higher educ_sec2 educ_incompl_sec2 educ_sec1 educ_incompl_sec1 educ_primary educ_incompl_primary educ_no_education  {
    use `"CH_stunt_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `stuntsocioallreg'
    save `"`stuntsocioallreg'"', replace
}

export excel using stunt_socio_allreg_consolidated.xlsx, replace
estimates drop Stu*

restore



* by region: stunting and socio-economic:  educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban own_bankaccount
foreach d of varlist educ_* water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_ch_stunt
			estimates store Stu`d'reg`i'
		}
		outreg2 [Stu`d'reg*] using CH_stunt_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
} 


* consolidate results
preserve

clear
tempfile stuntsocio
save `stuntsocio', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in urban bicycle mobile_phone television radio num_rooms_sleep cookfuel_other cookfuel_strawshrub cookfuel_wood cookfuel_charcoal electricity floor_other floor_cement floor_vinylasph floor_mats floor_palmbamb floor_woodplanks floor_earthsand roof_other roof_metal roof_palmbamb roof_thatchleaf toilet_open toilet_unimproved toilet_improved water_improve educ_dk educ_higher educ_sec2 educ_incompl_sec2 educ_sec1 educ_incompl_sec1 educ_primary educ_incompl_primary educ_no_education  {
    use `"CH_stunt_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `stuntsocio'
    save `"`stuntsocio'"', replace
}

export excel using stunt_socio_consolidated.xlsx, replace
estimates drop Stu*

restore


** all 4 regions: stunting and other assets
foreach d of varlist own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus {
		svy, subpop(if include == 1): reg `d' nt_ch_stunt
			estimates store Stu`d'all
		outreg2 [Stu`d'all] using CH_stunt_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile stuntassetsall
save `stuntassetsall', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in numown_zebus numown_poultry own_pigs own_ducks own_zebus own_poultry own_sheep own_goats own_horses own_cows own_livestock hectares_agricland animal_cart own_agricland {
    use `"CH_stunt_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	
	if "`f'" != "own_livestock" {
		keep if _n==5
	}
	else {
		keep if _n==6
	}
	display `"Appending `f'"'
    append using `stuntassetsall'
    save `"`stuntassetsall'"', replace
}



export excel using stunt_assets_allreg_consolidated.xlsx, replace
estimates drop Stu*

restore


** by region: stunting and other assets
foreach d of varlist own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_ch_stunt
			estimates store Stu`d'reg`i'
		}
		outreg2 [Stu`d'reg*] using CH_stunt_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile stuntassets
save `stuntassets', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in numown_zebus numown_poultry own_pigs own_ducks own_zebus own_poultry own_sheep own_goats own_horses own_cows own_livestock hectares_agricland animal_cart own_agricland {
    use `"CH_stunt_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	
	if "`f'" != "own_livestock" {
		keep if _n==5
	}
	else {
		keep if _n==6
	}
	display `"Appending `f'"'
    append using `stuntassets'
    save `"`stuntassets'"', replace
}



export excel using stunt_assets_consolidated.xlsx, replace
estimates drop Stu*

restore



** CHILD diet/MAD analysis

use "${clean}\child_diet_analysis.dta", clear

* set svy and some necessary vars
svyset hv021[pw=wt], strata(hv022) singleunit(centered)


g include = 0
replace include = 1 if inlist(region,25,51,52,53)

recode region (52=1 "Androy") (53=2 "Anosy") (51=3 "AtsimoAndrefana") (25=4 "AtismoAtsinanana"), pre(new)label(newreg)

* construct some needed vars
gen num_mbrs_dpndt=num_mbrs_14+num_mbrs_65

** create some mother vars to include in diet tables only
recode v717 (0=1 "Not working") (4/5=2 "Agriculture") (3=3 "Sales") (9=4 "Unskilled manual" ) (1/2 6/8 10 96=5 "Other"), gen(mother_occup)

*** create dummies for use in tables
local occup "not_work agric sales unskill other"
local occup_descrip "not_working agriculture sales unskilled_manual other"
local code "1 2 3 4 5"
forvalues i = 1/5 {
	local f: word `i' of `occup'
	local d: word `i' of `occup_descrip'
	local c: word `i' of `code'
	gen occup_`f' = cond(mother_occup == .,.,cond(mother_occup==`c', 1, 0))
	label variable occup_`f' "Mother occupation is `d'"
	label values occup_`f' noyes
}

*** check constructed variables
tab1 occup_*, m


**Table B-3: Additional Results for Research Question 3: Child MAD
** all 4 regions: diet and socio-demographics
foreach d of varlist hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio {
		svy, subpop(if include): reg `d' nt_mad
			estimates store Dt`d'all
		
		outreg2 [Dt`d'all] using CH_diet_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
}

* consolidate results

preserve

clear
tempfile dietdemoall
save `dietdemoall', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in dependency_ratio num_mbrs_dpndt num_child_under5 hhsize hh_head_age hh_head_female  {
    use `"CH_diet_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `dietdemoall'
    save `"`dietdemoall'"', replace
}

export excel using diet_demo_allreg_consolidated.xlsx, replace
estimates drop Dt*

restore 



* by region: diet and socio-demographics
foreach d of varlist hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_mad
			estimates store Dt`d'reg`i'
		}
		outreg2 [Dt`d'reg*] using CH_diet_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

* consolidate results

preserve

clear
tempfile dietdemo
save `dietdemo', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in dependency_ratio num_mbrs_dpndt num_child_under5 hhsize hh_head_age hh_head_female  {
    use `"CH_diet_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `dietdemo'
    save `"`dietdemo'"', replace
}

export excel using diet_demo_consolidated.xlsx, replace
estimates drop Dt*

restore


describe hh_head_female hh_head_age hhsize num_child_under5 num_mbrs_dpndt dependency_ratio occup_*



* all 4 regions: diet and socio-economic

* mother literacy
recode v155 (0=0 "None") (1/2 = 1 "Read part or whole sentence"), gen(lit_cat)
replace lit_cat=. if lit_cat==4

tab lit_cat v155, m

foreach d of varlist educ_* occup_* lit_cat ch_diar ch_ari water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban {
		svy, subpop(if include == 1): reg `d' nt_mad
			estimates store Dt`d'all
		
		outreg2 [Dt`d'all] using CH_diet_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile dietsocioall
save `dietsocioall', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in urban bicycle mobile_phone television radio num_rooms_sleep cookfuel_other cookfuel_strawshrub cookfuel_wood cookfuel_charcoal cookfuel_type cookfuel_categ electricity floor_other floor_cement floor_vinylasph floor_mats floor_palmbamb floor_woodplanks floor_earthsand floor_type floor_categ roof_other roof_metal roof_palmbamb roof_thatchleaf roof_type roof_categ toilet_open toilet_unimproved toilet_improved water_improve occup_other occup_unskill occup_sales occup_agric occup_not_work lit_cat ch_ari ch_diar educ_dk educ_higher educ_sec2 educ_incompl_sec2 educ_sec1 educ_incompl_sec1 educ_primary educ_incompl_primary educ_no_education {
    use `"CH_diet_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `dietsocioall'
    save `"`dietsocioall'"', replace
}

export excel using diet_socio_consolidated_allreg.xlsx, replace
estimates drop Dt*

restore


* diet and socio-economic
foreach d of varlist educ_* occup_* lit_cat ch_diar ch_ari  water_improve toilet_* roof_* floor_* electricity cookfuel_* num_rooms_sleep radio television mobile_phone bicycle urban {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_mad
			estimates store Dt`d'reg`i'
		}
		outreg2 [Dt`d'reg*] using CH_diet_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile dietsocio
save `dietsocio', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in urban bicycle mobile_phone television radio num_rooms_sleep cookfuel_other cookfuel_strawshrub cookfuel_wood cookfuel_charcoal cookfuel_type cookfuel_categ electricity floor_other floor_cement floor_vinylasph floor_mats floor_palmbamb floor_woodplanks floor_earthsand floor_type floor_categ roof_other roof_metal roof_palmbamb roof_thatchleaf roof_type roof_categ toilet_open toilet_unimproved toilet_improved water_improve ch_ari ch_diar lit_cat occup_other occup_unskill occup_sales occup_agric occup_not_work educ_dk educ_higher educ_sec2 educ_incompl_sec2 educ_sec1 educ_incompl_sec1 educ_primary educ_incompl_primary educ_no_education {
    use `"CH_diet_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	keep if _n==5 // only keep 5th row with data in it
    display `"Appending `f'"'
    append using `dietsocio'
    save `"`dietsocio'"', replace
}

export excel using diet_socio_consolidated.xlsx, replace
estimates drop Dt*

restore


** all 4 regions: diet and other assets
foreach d of varlist own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus {
		svy, subpop(if include == 1): reg `d' nt_mad
			estimates store Dt`d'all
		outreg2 [Dt`d'all] using CH_diet_`d'_allreg, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile dietassetsall
save `dietassetsall', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in numown_zebus numown_poultry own_pigs own_ducks own_zebus own_poultry own_sheep own_goats own_horses own_cows own_livestock hectares_agricland animal_cart own_agricland {
    use `"CH_diet_`f'_allreg_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	
	if "`f'" != "own_livestock" {
		keep if _n==5
	}
	else {
		keep if _n==6
	}
	display `"Appending `f'"'
    append using `dietassetsall'
    save `"`dietassetsall'"', replace
}



export excel using diet_assets_consolidated_allreg.xlsx, replace
estimates drop Dt*

restore


** diet and other assets
foreach d of varlist own_agricland animal_cart hectares_agricland own_livestock own_cows-own_pigs numown_poultry numown_zebus {
		forvalues i = 1/4 {
			svy, subpop(if include == 1 & newregion==`i'): reg `d' nt_mad
			estimates store Dt`d'reg`i'
		}
		outreg2 [Dt`d'reg*] using CH_diet_`d'_regions, dta noobs nor2 nose nonotes nocons label replace
		
}

preserve

clear
tempfile dietassets
save `dietassets', emptyok

** append results from area and export to XLS
*** note that appending stacks them in opposite order, so reverse order here
foreach f in numown_zebus numown_poultry own_pigs own_ducks own_zebus own_poultry own_sheep own_goats own_horses own_cows own_livestock hectares_agricland animal_cart own_agricland {
    use `"CH_diet_`f'_regions_dta.dta"', clear
	describe
    replace v1 = `"`f'"'
	
	if "`f'" != "own_livestock" {
		keep if _n==5
	}
	else {
		keep if _n==6
	}
	display `"Appending `f'"'
    append using `dietassets'
    save `"`dietassets'"', replace
}



export excel using diet_assets_consolidated.xlsx, replace
estimates drop Dt*

restore